![Voucherify Python SDK](././voucherify-python-sdk.png)

## Official [Voucherify](https://www.voucherify.io/) SDK for Python

Voucherify empowers marketers and developers with flexible building blocks to come up with, implement, and track targeted promotional campaigns.

Learn more about Voucherify by visiting [our site](https://www.voucherify.io).

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) based on our [Documentation](https://docs.voucherify.io/docs/introduction) with v2018-08-01 version.

The legacy version of Python SDK could be found [here](https://github.com/voucherifyio/voucherify-python-sdk/releases/tag/v2.2.2)

## 📝 Documentation

You will find detailed description and example responses at our [official documentation](https://docs.voucherify.io/reference). Most method headers point to more detailed descriptions of arguments you can use.

📚 Want to learn more? Visit our [official site](https://www.voucherify.io) or our [Success Portal](https://success.voucherify.io).

👽 Having troubles? Check our [Help center](https://support.voucherify.io/).

🧪 Looking for promotion ideas? Check our [Cookbook](https://cookbook.voucherify.io/) to get an inspiration.

🐛 Encounter a bug? Please file a report in the [Issues](https://github.com/voucherifyio/voucherify-python-sdk/issues).

✅ Supported endpoint can be found [here](./ENDPOINTS-COVERAGE.md)

## Requirements.

Python 3.7+

## Installation

To install the API client library to your local Maven repository, simply execute:

```sh
pip install 'Voucherify'
```

Then import the package:

```python
import voucherify
```

## 🚀 Running code

Please follow the [installation](#installation) instruction and execute the following Python code:

```python
import os
import voucherify
from dotenv import load_dotenv

load_dotenv()

HOST = os.getenv('VOUCHERIFY_HOST', 'https://api.voucherify.io')
X_APP_ID = os.getenv('X_APP_ID')
X_APP_TOKEN = os.getenv('X_APP_TOKEN')

if not X_APP_ID or not X_APP_TOKEN:
    raise ValueError("X_APP_ID and X_APP_TOKEN must be set in the .env file.")

configuration = voucherify.Configuration(
    host=HOST,
    api_key={
            "X-App-Id": X_APP_ID,
            "X-App-Token": X_APP_TOKEN
        }
)
# Debugging line
api_key_id = configuration.get_api_key_with_prefix('X-App-Id')
api_key_token = configuration.get_api_key_with_prefix('X-App-Token')

# Print whether both API keys are present and valid
are_keys_present = bool(api_key_id) and bool(api_key_token)
print(f"Configuration loaded: {are_keys_present}")

if(are_keys_present):
    with voucherify.ApiClient(configuration) as api_client:
        customers_api_instance = voucherify.CustomersApi(api_client)

        try:
            result = customers_api_instance.list_customers()
            print(result)

        except voucherifyClient.ApiException as e:
            self.fail(e)
```

It may be useful to check the tests implementation in the folder **tests** `(./__tests__)`

## 🐳 Running local tests with docker

1. Copy `.env.example` to `.env` and fill in the values.
2. Run `docker build -t python .` to build the image.
3. Run `docker run --rm python` to run the tests and delete container immediately after.

## 🛠️ Contributing

Read more about how to Contribute to Voucherify Python SDK by visiting main repo [GENERATING-SDKS.md](https://github.com/voucherifyio/voucherify-openapi/blob/master/GENERATING-SDKS.md)

Remember that this SDK is auto generated (except of the tests) so changes made here will be overwritten by generator.

## 📅 Changelog

- **2024-11-26** - `5.0.2`
  - Added support for `STANDALONE` campaign type.
  - Added optional `metadata` in `OrderCalculatedItemSku`
  - New possible value of `ParameterExpandListCampaigns`
  - New optional `error` parameter in `Error`
  - Updated `LoyaltyCardTransactionDetailsBalance`
- **2024-11-04** - `5.0.1`
  - Added support for returning `campaign_id` and `campaign_name` in stackable validation endpoint, when `redeemable` option is expanded
- **2024-10-28** - `5.0.0`
  - Added missing `enums` in few filters models
  - !!! BREAKING CHANGES !!!
    - VouchersApi.generateRandomCode now requires `VouchersCreateResponseBody` instead of plain `object`
    - property `product` in model `Discount` now uses `DiscountProduct` instead of `SimpleProductDiscountUnit`
    - property `filters` of model `ExportsCreateRequestBodyParameters` now uses plain `object` instead of `ExportsCreateRequestBodyParametersFilters`
- **2024-10-25** - `4.0.0`
    - Fix object parsing in query. For example `filters` while listing redemptions.
    - !!! BREAKING CHANGES !!!
        - Remove support for `/client/v1/customers/{customerId}/consents` - put `Update Customer's consents (client-side) [Deprecated]`
        - Pagination changed on listing card transactions(listLoyaltyCardTransactions) - NO `page` param is supported - use `starting_after_id` instead.
        - Pagination changed on listing voucher transactions(listVoucherTransactions) - NO `page` param is supported - use `starting_after_id` instead.
        - ApplicableToEffect - changed - `EVERY` -> `TO_EVERY`, `CHEAPEST` -> `TO_CHEAPEST`, `MOST_EXPENSIVE` -> `TO_MOST_EXPENSIVE`, 2 new values introduced.
        - `listPublications` parameter `filters` have changed - now uses `ParameterFiltersListPublications` instead of `String`
        - `ParameterFiltersListRedemptions` and `ParameterFiltersListCustomerRedeemables` have been updated
        - enum `LUCKY_DRAW`, `LUCKY_DRAW_CODE`, `VOUCHER_LUCKY_DRAW_CODE`, `CAMPAIGN_LUCKY_DRAW` have been deleted from everywhere and no longer supported
        - CampaignsUpdateRequestBody - properties `activityDurationAfterPublishing`, `joinOnce`, `autoJoin`, `type`, `uniqueWinners`, `uniqueWinnersPerDraw` and enum `AUTO_UPDATE` | `STATIC` have been deleted and no longer supported
        - `updateCustomersConsents` has been deleted and no longer supported
        - `FilterConditionsDateTimeConditions` model has been renamed to `FilterConditionsDateTime`
        - FilterConditionsDateTime - `conditions` has been divided on `$after`, `$before`, `$hasValue`, `$isUnknown`, `moreThan`, `lessThan` properties
        - ParamterFiltersListCustomerRedeemables - model name of `createdAt` has been renamed from `FilterConditionsDateTime` to `ParameterFiltersListCustomerRedeemablesCreatedAt`
        - `filter` property in schemas ProductCollectionsCreateRequestBody, ProductCollectionsCreateResponseBody, ProductCollectionsItem and ProductCollectionsGetResponseBody has changed. Uses plain `object`.
        - `discount` property in schema CampaignsUpdateRequestBody now uses `Discount` model
        - properties `winnersCount`, `uniqueWinnersPerDraw`, `uniqueWinners` in model `CampaignsUpdateRequestBody` were deleted.
        - property `stackingRulesType` were deleted from models `CategoriesGetResponseBody`, `Category`
        - property `categories` in model `ClientValidationsValidateResponseBodyRedeemablesItem` uses now Array<CategoryWithStackingRulesType> model
        - model `ParameterFiltersListCustomerRedeemablesCampaignId` has been fixed, can use junction properly.
        - model `ParameterFiltersListRedemptions` has been fixed, can use junction properly.
        - property `filter` in model `ProductCollectionsCreateRequestBody` now uses plain Object
        - property `categories` in model `QualificationsRedeemable` now uses `Array<CategoryWithStackingRulesType>`
    - Added support:
        - /v1/metadata-schemas - get `List Metadata Schemas`
        - /v1/metadata-schemas/{resource} - get `Get Metadata Schema`
        - /v1/locations - `List Locations`
        - /v1/locations/{locationId} - get `Get Location`
        - /v1/referrals/{campaignId}/members/{memberId}/holders - post `Add Referral Code Holders`
        - /v1/referrals/{campaignId}/members/{memberId}/holders - get `List Referral Code Holders`
        - /v1/referrals/{campaignId}/members/{memberId}/holders/{holderId} - delete `Remove Referral Card Holder`
        - /v1/referrals/members/{memberId}/holders - post `Add Referral Code Holders`
        - /v1/referrals/members/{memberId}/holders - get `List Referral Code Holders`
        - /v1/referrals/members/{memberId}/holders/{holderId} - delete `Remove Referral Card Holder`
        - /v1/trash-bin - get `List Bin Entries`
        - /v1/trash-bin/{binEntryId} - delete `Delete Bin Entry`
        - /v1/templates/campaigns - get `List Campaign Templates`
        - /v1/templates/campaigns - post `Create Campaign Template`
        - /v1/templates/campaigns/{campaignTemplateId} - get `Get Campaign Template`
        - /v1/templates/campaigns/{campaignTemplateId} - put `Update Campaign Template`
        - /v1/templates/campaigns/{campaignTemplateId} - delete `Delete Campaign Template`
        - /v1/templates/campaigns/{campaignTemplateId}/campaign-setup - post `Create Campaign From Template`
        - /v1/templates/campaigns/{campaignTemplateId}/tier-setup - post `Add Promotion Tier From Template`
        - /management/v1/projects - post `Create Project`
        - /management/v1/projects - get `List Projects`
        - /management/v1/projects/{projectId} - get `Get Project`
        - /management/v1/projects/{projectId} - put `Update Project`
        - /management/v1/projects/{projectId} - delete `Delete Project`
        - /management/v1/projects/{projectId}/users - post `Assign User`
        - /management/v1/projects/{projectId}/users/{userId} - put `Update User`
        - /management/v1/projects/{projectId}/users/{userId} - delete `Unassign User`
        - /management/v1/projects/users/invite - post `Invite a New User`
        - /management/v1/projects/{projectId}/templates/campaigns - get `List Campaign Templates`
        - /management/v1/projects/{projectId}/templates/campaigns/{campaignTemplateId}/copy - post `Copy Campaign Template to a Project`
        - /management/v1/projects/{projectId}/stacking-rules - post `Create Stacking Rules`
        - /management/v1/projects/{projectId}/stacking-rules - get `List Stacking Rules`
        - /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} - get `Get Stacking Rules`
        - /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} - put `Update Stacking Rules`
        - /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} - delete `Delete Stacking Rules`
        - /management/v1/projects/{projectId}/metadata-schemas - post `Create Metadata Schema`
        - /management/v1/projects/{projectId}/metadata-schemas - get `List Metadata Schemas`
        - /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} - get `Get Metadata Schema`
        - /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} - put `Update Metadata Schema`
        - /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} - delete `Delete Metadata Schema`
        - /management/v1/projects/{projectId}/custom-event-schemas - post `Create Custom Event Schema`
        - /management/v1/projects/{projectId}/custom-event-schemas - get `List Custom Event Schemas`
        - /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} - get `Get Custom Event Schema`
        - /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} - put `Update Custom Event Schema`
        - /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} - delete `Delete Custom Event Schema`
        - /management/v1/projects/{projectId}/webhooks - post `Create Webhook`
        - /management/v1/projects/{projectId}/webhooks - get `List Webhooks`
        - /management/v1/projects/{projectId}/webhooks/{webhookId} - get `Get Webhook`
        - /management/v1/projects/{projectId}/webhooks/{webhookId} - put `Update Webhook`
        - /management/v1/projects/{projectId}/webhooks/{webhookId} - delete `Delete Webhook`
        - /management/v1/projects/{projectId}/branding - post `Create Brand`
        - /management/v1/projects/{projectId}/branding - get `List Brands`
        - /management/v1/projects/{projectId}/branding/{brandingId} - get `Get Brand`
        - /management/v1/projects/{projectId}/branding/{brandingId} - put `Update Brand`
        - /management/v1/projects/{projectId}/branding/{brandingId} - delete `Delete Brand`
- **2024-09-18** - `3.0.0`
    -  The new version of the SDK includes coverage for all the most commonly used Voucherify endpoints and supports typed models.

*Previous versions of the API are no longer supported, and we highly recommend upgrading to version 3.0.0, which is now designated as Long-Term Support (LTS).*

*Changelog for previous versions could be found in [here](./DEPRECATED_CHANGELOG.md)*

## 🔐 Documentation for Authorization

```python
import os
import voucherify
from dotenv import load_dotenv

load_dotenv()

HOST = os.getenv('VOUCHERIFY_HOST', 'https://api.voucherify.io')
X_APP_ID = os.getenv('X_APP_ID')
X_APP_TOKEN = os.getenv('X_APP_TOKEN')

if not X_APP_ID or not X_APP_TOKEN:
    raise ValueError("X_APP_ID and X_APP_TOKEN must be set in the .env file.")

configuration = voucherify.Configuration(
    host=HOST,
    api_key={
            "X-App-Id": X_APP_ID,
            "X-App-Token": X_APP_TOKEN
        }
)
# Debugging line
api_key_id = configuration.get_api_key_with_prefix('X-App-Id')
api_key_token = configuration.get_api_key_with_prefix('X-App-Token')

# Print whether both API keys are present and valid
are_keys_present = bool(api_key_id) and bool(api_key_token)
print(f"Configuration loaded: {are_keys_present}")
```

then use

```python
import voucherify

(...)
    with voucherify.ApiClient(configuration) as api_client:
```

## Documentation for API Endpoints

All URIs are relative to *https://api.voucherify.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AsyncActionsApi* | [**get_async_action**](docs/AsyncActionsApi.md#get_async_action) | **GET** /v1/async-actions/{asyncActionId} | Get Async Action
*AsyncActionsApi* | [**list_async_actions**](docs/AsyncActionsApi.md#list_async_actions) | **GET** /v1/async-actions | List Async Actions
*BinApi* | [**delete_bin_entry**](docs/BinApi.md#delete_bin_entry) | **DELETE** /v1/trash-bin/{binEntryId} | Delete Bin Entry
*BinApi* | [**list_bin_entries**](docs/BinApi.md#list_bin_entries) | **GET** /v1/trash-bin | List Bin Entries
*CampaignsApi* | [**add_voucher_with_specific_code_to_campaign**](docs/CampaignsApi.md#add_voucher_with_specific_code_to_campaign) | **POST** /v1/campaigns/{campaignId}/vouchers/{code} | Add Voucher with Specific Code to Campaign
*CampaignsApi* | [**add_vouchers_to_campaign**](docs/CampaignsApi.md#add_vouchers_to_campaign) | **POST** /v1/campaigns/{campaignId}/vouchers | Add Vouchers to Campaign
*CampaignsApi* | [**create_campaign**](docs/CampaignsApi.md#create_campaign) | **POST** /v1/campaigns | Create Campaign
*CampaignsApi* | [**delete_campaign**](docs/CampaignsApi.md#delete_campaign) | **DELETE** /v1/campaigns/{campaignId} | Delete Campaign
*CampaignsApi* | [**disable_campaign**](docs/CampaignsApi.md#disable_campaign) | **POST** /v1/campaigns/{campaignId}/disable | Disable Campaign
*CampaignsApi* | [**enable_campaign**](docs/CampaignsApi.md#enable_campaign) | **POST** /v1/campaigns/{campaignId}/enable | Enable Campaign
*CampaignsApi* | [**get_campaign**](docs/CampaignsApi.md#get_campaign) | **GET** /v1/campaigns/{campaignId} | Get Campaign
*CampaignsApi* | [**import_vouchers_to_campaign**](docs/CampaignsApi.md#import_vouchers_to_campaign) | **POST** /v1/campaigns/{campaignId}/import | Import Vouchers to Campaign
*CampaignsApi* | [**import_vouchers_to_campaign_using_csv**](docs/CampaignsApi.md#import_vouchers_to_campaign_using_csv) | **POST** /v1/campaigns/{campaignId}/importCSV | Import Vouchers to Campaign by CSV
*CampaignsApi* | [**list_campaigns**](docs/CampaignsApi.md#list_campaigns) | **GET** /v1/campaigns | List Campaigns
*CampaignsApi* | [**update_campaign**](docs/CampaignsApi.md#update_campaign) | **PUT** /v1/campaigns/{campaignId} | Update Campaign
*CategoriesApi* | [**create_category**](docs/CategoriesApi.md#create_category) | **POST** /v1/categories | Create Category
*CategoriesApi* | [**delete_category**](docs/CategoriesApi.md#delete_category) | **DELETE** /v1/categories/{categoryId} | Delete Category
*CategoriesApi* | [**get_category**](docs/CategoriesApi.md#get_category) | **GET** /v1/categories/{categoryId} | Get Category
*CategoriesApi* | [**list_categories**](docs/CategoriesApi.md#list_categories) | **GET** /v1/categories | List Categories
*CategoriesApi* | [**update_category**](docs/CategoriesApi.md#update_category) | **PUT** /v1/categories/{categoryId} | Update Category
*ClientSideApi* | [**check_eligibility_client_side**](docs/ClientSideApi.md#check_eligibility_client_side) | **POST** /client/v1/qualifications | Check Eligibility (client-side)
*ClientSideApi* | [**list_promotion_tiers_client_side**](docs/ClientSideApi.md#list_promotion_tiers_client_side) | **GET** /client/v1/promotions/tiers | List Promotion Tiers (client-side)
*ClientSideApi* | [**redeem_stacked_discounts_client_side**](docs/ClientSideApi.md#redeem_stacked_discounts_client_side) | **POST** /client/v1/redemptions | Redeem Stackable Discounts (client-side)
*ClientSideApi* | [**track_custom_event_client_side**](docs/ClientSideApi.md#track_custom_event_client_side) | **POST** /client/v1/events | Track Custom Event (client-side)
*ClientSideApi* | [**validate_stacked_discounts_client_side**](docs/ClientSideApi.md#validate_stacked_discounts_client_side) | **POST** /client/v1/validations | Validate Stackable Discounts (client-side)
*CustomersApi* | [**create_customer**](docs/CustomersApi.md#create_customer) | **POST** /v1/customers | Create Customer
*CustomersApi* | [**customer_permanently_deletion**](docs/CustomersApi.md#customer_permanently_deletion) | **POST** /v1/customers/{customerId}/permanent-deletion | Delete Customer Permanently
*CustomersApi* | [**delete_customer**](docs/CustomersApi.md#delete_customer) | **DELETE** /v1/customers/{customerId} | Delete Customer
*CustomersApi* | [**get_customer**](docs/CustomersApi.md#get_customer) | **GET** /v1/customers/{customerId} | Get Customer
*CustomersApi* | [**import_customers_using_csv**](docs/CustomersApi.md#import_customers_using_csv) | **POST** /v1/customers/importCSV | Import and Update Customers using CSV
*CustomersApi* | [**list_customer_activity**](docs/CustomersApi.md#list_customer_activity) | **GET** /v1/customers/{customerId}/activity | List Customer Activity
*CustomersApi* | [**list_customer_redeemables**](docs/CustomersApi.md#list_customer_redeemables) | **GET** /v1/customers/{customerId}/redeemables | List Customer&#39;s Redeemables
*CustomersApi* | [**list_customer_segments**](docs/CustomersApi.md#list_customer_segments) | **GET** /v1/customers/{customerId}/segments | List Customer&#39;s Segments
*CustomersApi* | [**list_customers**](docs/CustomersApi.md#list_customers) | **GET** /v1/customers | List Customers
*CustomersApi* | [**update_customer**](docs/CustomersApi.md#update_customer) | **PUT** /v1/customers/{customerId} | Update Customer
*CustomersApi* | [**update_customers_in_bulk**](docs/CustomersApi.md#update_customers_in_bulk) | **POST** /v1/customers/bulk/async | Update Customers in Bulk
*CustomersApi* | [**update_customers_metadata_in_bulk**](docs/CustomersApi.md#update_customers_metadata_in_bulk) | **POST** /v1/customers/metadata/async | Update Customers&#39; Metadata in Bulk
*EventsApi* | [**track_custom_event**](docs/EventsApi.md#track_custom_event) | **POST** /v1/events | Track Custom Event
*ExportsApi* | [**create_export**](docs/ExportsApi.md#create_export) | **POST** /v1/exports | Create Export
*ExportsApi* | [**delete_export**](docs/ExportsApi.md#delete_export) | **DELETE** /v1/exports/{exportId} | Delete Export
*ExportsApi* | [**download_export**](docs/ExportsApi.md#download_export) | **GET** /v1/exports/{export_Id} | Download Export
*ExportsApi* | [**get_export**](docs/ExportsApi.md#get_export) | **GET** /v1/exports/{exportId} | Get Export
*ExportsApi* | [**list_exports**](docs/ExportsApi.md#list_exports) | **GET** /v1/exports | List Exports
*LocationsApi* | [**get_location**](docs/LocationsApi.md#get_location) | **GET** /v1/locations/{locationId} | Get Location
*LocationsApi* | [**list_locations**](docs/LocationsApi.md#list_locations) | **GET** /v1/locations | List Locations
*LoyaltiesApi* | [**add_member**](docs/LoyaltiesApi.md#add_member) | **POST** /v1/loyalties/{campaignId}/members | Add Member
*LoyaltiesApi* | [**create_earning_rule**](docs/LoyaltiesApi.md#create_earning_rule) | **POST** /v1/loyalties/{campaignId}/earning-rules | Create Earning Rule
*LoyaltiesApi* | [**create_in_bulk_loyalty_tiers**](docs/LoyaltiesApi.md#create_in_bulk_loyalty_tiers) | **POST** /v1/loyalties/{campaignId}/tiers | Create loyalty tiers
*LoyaltiesApi* | [**create_loyalty_program**](docs/LoyaltiesApi.md#create_loyalty_program) | **POST** /v1/loyalties | Create Loyalty Campaign
*LoyaltiesApi* | [**create_points_expiration_export**](docs/LoyaltiesApi.md#create_points_expiration_export) | **POST** /v1/loyalties/{campaignId}/points-expiration/export | Create Points Expiration Export
*LoyaltiesApi* | [**create_reward_assignment1**](docs/LoyaltiesApi.md#create_reward_assignment1) | **POST** /v1/loyalties/{campaignId}/rewards | Create Reward Assignment
*LoyaltiesApi* | [**delete_earning_rule**](docs/LoyaltiesApi.md#delete_earning_rule) | **DELETE** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId} | Delete Earning Rule
*LoyaltiesApi* | [**delete_loyalty_program**](docs/LoyaltiesApi.md#delete_loyalty_program) | **DELETE** /v1/loyalties/{campaignId} | Delete Loyalty Campaign
*LoyaltiesApi* | [**delete_reward_assignment1**](docs/LoyaltiesApi.md#delete_reward_assignment1) | **DELETE** /v1/loyalties/{campaignId}/rewards/{assignmentId} | Delete Reward Assignment
*LoyaltiesApi* | [**disable_earning_rule**](docs/LoyaltiesApi.md#disable_earning_rule) | **POST** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId}/disable | Disable Earning Rule
*LoyaltiesApi* | [**enable_earning_rule**](docs/LoyaltiesApi.md#enable_earning_rule) | **POST** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId}/enable | Enable Earning Rule
*LoyaltiesApi* | [**export_loyalty_card_transactions**](docs/LoyaltiesApi.md#export_loyalty_card_transactions) | **POST** /v1/loyalties/members/{memberId}/transactions/export | Export Loyalty Card Transactions
*LoyaltiesApi* | [**export_loyalty_card_transactions1**](docs/LoyaltiesApi.md#export_loyalty_card_transactions1) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/transactions/export | Export Loyalty Card Transactions
*LoyaltiesApi* | [**get_earning_rule**](docs/LoyaltiesApi.md#get_earning_rule) | **GET** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId} | Get Earning Rule
*LoyaltiesApi* | [**get_loyalty_program**](docs/LoyaltiesApi.md#get_loyalty_program) | **GET** /v1/loyalties/{campaignId} | Get Loyalty Campaign
*LoyaltiesApi* | [**get_loyalty_tier**](docs/LoyaltiesApi.md#get_loyalty_tier) | **GET** /v1/loyalties/{campaignId}/tiers/{loyaltyTierId} | Get Loyalty Tier
*LoyaltiesApi* | [**get_member**](docs/LoyaltiesApi.md#get_member) | **GET** /v1/loyalties/members/{memberId} | Get Member
*LoyaltiesApi* | [**get_member1**](docs/LoyaltiesApi.md#get_member1) | **GET** /v1/loyalties/{campaignId}/members/{memberId} | Get Member
*LoyaltiesApi* | [**get_reward_assignment1**](docs/LoyaltiesApi.md#get_reward_assignment1) | **GET** /v1/loyalties/{campaignId}/reward-assignments/{assignmentId} | Get Reward Assignment
*LoyaltiesApi* | [**get_reward_assignment2**](docs/LoyaltiesApi.md#get_reward_assignment2) | **GET** /v1/loyalties/{campaignId}/rewards/{assignmentId} | Get Reward Assignment
*LoyaltiesApi* | [**get_reward_details**](docs/LoyaltiesApi.md#get_reward_details) | **GET** /v1/loyalties/{campaignId}/reward-assignments/{assignmentId}/reward | Get Reward Details
*LoyaltiesApi* | [**list_earning_rules**](docs/LoyaltiesApi.md#list_earning_rules) | **GET** /v1/loyalties/{campaignId}/earning-rules | List Earning Rules
*LoyaltiesApi* | [**list_loyalty_card_transactions**](docs/LoyaltiesApi.md#list_loyalty_card_transactions) | **GET** /v1/loyalties/members/{memberId}/transactions | List Loyalty Card Transactions
*LoyaltiesApi* | [**list_loyalty_card_transactions1**](docs/LoyaltiesApi.md#list_loyalty_card_transactions1) | **GET** /v1/loyalties/{campaignId}/members/{memberId}/transactions | List Loyalty Card Transactions
*LoyaltiesApi* | [**list_loyalty_programs**](docs/LoyaltiesApi.md#list_loyalty_programs) | **GET** /v1/loyalties | List Loyalty Campaigns
*LoyaltiesApi* | [**list_loyalty_tier_earning_rules**](docs/LoyaltiesApi.md#list_loyalty_tier_earning_rules) | **GET** /v1/loyalties/{campaignId}/tiers/{loyaltyTierId}/earning-rules | List Loyalty Tier Earning Rules
*LoyaltiesApi* | [**list_loyalty_tier_rewards**](docs/LoyaltiesApi.md#list_loyalty_tier_rewards) | **GET** /v1/loyalties/{campaignId}/tiers/{loyaltyTierId}/rewards | List Loyalty Tier Rewards
*LoyaltiesApi* | [**list_loyalty_tiers**](docs/LoyaltiesApi.md#list_loyalty_tiers) | **GET** /v1/loyalties/{campaignId}/tiers | List Loyalty Tiers
*LoyaltiesApi* | [**list_member_activity**](docs/LoyaltiesApi.md#list_member_activity) | **GET** /v1/loyalties/members/{memberId}/activity | List Member Activity
*LoyaltiesApi* | [**list_member_activity1**](docs/LoyaltiesApi.md#list_member_activity1) | **GET** /v1/loyalties/{campaignId}/members/{memberId}/activity | List Member Activity
*LoyaltiesApi* | [**list_member_loyalty_tier**](docs/LoyaltiesApi.md#list_member_loyalty_tier) | **GET** /v1/loyalties/members/{memberId}/tiers | List Member&#39;s Loyalty Tiers
*LoyaltiesApi* | [**list_member_rewards**](docs/LoyaltiesApi.md#list_member_rewards) | **GET** /v1/loyalties/members/{memberId}/rewards | List Member Rewards
*LoyaltiesApi* | [**list_members**](docs/LoyaltiesApi.md#list_members) | **GET** /v1/loyalties/{campaignId}/members | List Members
*LoyaltiesApi* | [**list_points_expiration**](docs/LoyaltiesApi.md#list_points_expiration) | **GET** /v1/loyalties/{campaignId}/members/{memberId}/points-expiration | Get Points Expiration
*LoyaltiesApi* | [**list_reward_assignments1**](docs/LoyaltiesApi.md#list_reward_assignments1) | **GET** /v1/loyalties/{campaignId}/reward-assignments | List Reward Assignments
*LoyaltiesApi* | [**list_reward_assignments2**](docs/LoyaltiesApi.md#list_reward_assignments2) | **GET** /v1/loyalties/{campaignId}/rewards | List Reward Assignments
*LoyaltiesApi* | [**redeem_reward**](docs/LoyaltiesApi.md#redeem_reward) | **POST** /v1/loyalties/members/{memberId}/redemption | Redeem Reward
*LoyaltiesApi* | [**redeem_reward1**](docs/LoyaltiesApi.md#redeem_reward1) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/redemption | Redeem Reward
*LoyaltiesApi* | [**transfer_points**](docs/LoyaltiesApi.md#transfer_points) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/transfers | Transfer Loyalty Points
*LoyaltiesApi* | [**update_earning_rule**](docs/LoyaltiesApi.md#update_earning_rule) | **PUT** /v1/loyalties/{campaignId}/earning-rules/{earningRuleId} | Update Earning Rule
*LoyaltiesApi* | [**update_loyalty_card_balance**](docs/LoyaltiesApi.md#update_loyalty_card_balance) | **POST** /v1/loyalties/members/{memberId}/balance | Add or Remove Loyalty Card Balance
*LoyaltiesApi* | [**update_loyalty_card_balance1**](docs/LoyaltiesApi.md#update_loyalty_card_balance1) | **POST** /v1/loyalties/{campaignId}/members/{memberId}/balance | Add or Remove Loyalty Card Balance
*LoyaltiesApi* | [**update_loyalty_program**](docs/LoyaltiesApi.md#update_loyalty_program) | **PUT** /v1/loyalties/{campaignId} | Update Loyalty Campaign
*LoyaltiesApi* | [**update_reward_assignment1**](docs/LoyaltiesApi.md#update_reward_assignment1) | **PUT** /v1/loyalties/{campaignId}/rewards/{assignmentId} | Update Reward Assignment
*ManagementApi* | [**assign_user**](docs/ManagementApi.md#assign_user) | **POST** /management/v1/projects/{projectId}/users | Assign User
*ManagementApi* | [**create_brand**](docs/ManagementApi.md#create_brand) | **POST** /management/v1/projects/{projectId}/branding | Create Brand
*ManagementApi* | [**create_custom_event_schema**](docs/ManagementApi.md#create_custom_event_schema) | **POST** /management/v1/projects/{projectId}/custom-event-schemas | Create Custom Event Schema
*ManagementApi* | [**create_metadata_schema**](docs/ManagementApi.md#create_metadata_schema) | **POST** /management/v1/projects/{projectId}/metadata-schemas | Create Metadata Schema
*ManagementApi* | [**create_project**](docs/ManagementApi.md#create_project) | **POST** /management/v1/projects | Create Project
*ManagementApi* | [**create_stacking_rules**](docs/ManagementApi.md#create_stacking_rules) | **POST** /management/v1/projects/{projectId}/stacking-rules | Create Stacking Rules
*ManagementApi* | [**create_webhook**](docs/ManagementApi.md#create_webhook) | **POST** /management/v1/projects/{projectId}/webhooks | Create Webhook
*ManagementApi* | [**delete_brand**](docs/ManagementApi.md#delete_brand) | **DELETE** /management/v1/projects/{projectId}/branding/{brandingId} | Delete Brand
*ManagementApi* | [**delete_custom_event_schema**](docs/ManagementApi.md#delete_custom_event_schema) | **DELETE** /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} | Delete Custom Event Schema
*ManagementApi* | [**delete_metadata_schema**](docs/ManagementApi.md#delete_metadata_schema) | **DELETE** /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} | Delete Metadata Schema
*ManagementApi* | [**delete_project**](docs/ManagementApi.md#delete_project) | **DELETE** /management/v1/projects/{projectId} | Delete Project
*ManagementApi* | [**delete_stacking_rules**](docs/ManagementApi.md#delete_stacking_rules) | **DELETE** /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} | Delete Stacking Rules
*ManagementApi* | [**delete_webhook**](docs/ManagementApi.md#delete_webhook) | **DELETE** /management/v1/projects/{projectId}/webhooks/{webhookId} | Delete Webhook
*ManagementApi* | [**get_brand**](docs/ManagementApi.md#get_brand) | **GET** /management/v1/projects/{projectId}/branding/{brandingId} | Get Brand
*ManagementApi* | [**get_custom_event_schema**](docs/ManagementApi.md#get_custom_event_schema) | **GET** /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} | Get Custom Event Schema
*ManagementApi* | [**get_metadata_schema1**](docs/ManagementApi.md#get_metadata_schema1) | **GET** /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} | Get Metadata Schema
*ManagementApi* | [**get_project**](docs/ManagementApi.md#get_project) | **GET** /management/v1/projects/{projectId} | Get Project
*ManagementApi* | [**get_stacking_rules**](docs/ManagementApi.md#get_stacking_rules) | **GET** /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} | Get Stacking Rules
*ManagementApi* | [**get_user**](docs/ManagementApi.md#get_user) | **GET** /management/v1/projects/{projectId}/users/{userId} | Get User
*ManagementApi* | [**get_webhook**](docs/ManagementApi.md#get_webhook) | **GET** /management/v1/projects/{projectId}/webhooks/{webhookId} | Get Webhook
*ManagementApi* | [**invite_user**](docs/ManagementApi.md#invite_user) | **POST** /management/v1/projects/users/invite | Invite a New User
*ManagementApi* | [**list_brands**](docs/ManagementApi.md#list_brands) | **GET** /management/v1/projects/{projectId}/branding | List Brands
*ManagementApi* | [**list_custom_event_schemas**](docs/ManagementApi.md#list_custom_event_schemas) | **GET** /management/v1/projects/{projectId}/custom-event-schemas | List Custom Event Schemas
*ManagementApi* | [**list_metadata_schemas1**](docs/ManagementApi.md#list_metadata_schemas1) | **GET** /management/v1/projects/{projectId}/metadata-schemas | List Metadata Schemas
*ManagementApi* | [**list_projects**](docs/ManagementApi.md#list_projects) | **GET** /management/v1/projects | List Projects
*ManagementApi* | [**list_stacking_rules**](docs/ManagementApi.md#list_stacking_rules) | **GET** /management/v1/projects/{projectId}/stacking-rules | List Stacking Rules
*ManagementApi* | [**list_users**](docs/ManagementApi.md#list_users) | **GET** /management/v1/projects/{projectId}/users | List Users
*ManagementApi* | [**list_webhooks**](docs/ManagementApi.md#list_webhooks) | **GET** /management/v1/projects/{projectId}/webhooks | List Webhooks
*ManagementApi* | [**management_copy_campaign_template**](docs/ManagementApi.md#management_copy_campaign_template) | **POST** /management/v1/projects/{projectId}/templates/campaigns/{campaignTemplateId}/copy | Copy Campaign Template to a Project
*ManagementApi* | [**management_list_campaign_templates**](docs/ManagementApi.md#management_list_campaign_templates) | **GET** /management/v1/projects/{projectId}/templates/campaigns | List Campaign Templates
*ManagementApi* | [**unassign_user**](docs/ManagementApi.md#unassign_user) | **DELETE** /management/v1/projects/{projectId}/users/{userId} | Unassign User
*ManagementApi* | [**update_brand**](docs/ManagementApi.md#update_brand) | **PUT** /management/v1/projects/{projectId}/branding/{brandingId} | Update Brand
*ManagementApi* | [**update_custom_event_schema**](docs/ManagementApi.md#update_custom_event_schema) | **PUT** /management/v1/projects/{projectId}/custom-event-schemas/{customEventSchemaId} | Update Custom Event Schema
*ManagementApi* | [**update_metadata_schema**](docs/ManagementApi.md#update_metadata_schema) | **PUT** /management/v1/projects/{projectId}/metadata-schemas/{metadataSchemaId} | Update Metadata Schema
*ManagementApi* | [**update_project**](docs/ManagementApi.md#update_project) | **PUT** /management/v1/projects/{projectId} | Update Project
*ManagementApi* | [**update_stacking_rules**](docs/ManagementApi.md#update_stacking_rules) | **PUT** /management/v1/projects/{projectId}/stacking-rules/{stackingRulesId} | Update Stacking Rules
*ManagementApi* | [**update_user**](docs/ManagementApi.md#update_user) | **PUT** /management/v1/projects/{projectId}/users/{userId} | Update User
*ManagementApi* | [**update_webhook**](docs/ManagementApi.md#update_webhook) | **PUT** /management/v1/projects/{projectId}/webhooks/{webhookId} | Update Webhook
*MetadataSchemasApi* | [**get_metadata_schema**](docs/MetadataSchemasApi.md#get_metadata_schema) | **GET** /v1/metadata-schemas/{resource} | Get Metadata Schema
*MetadataSchemasApi* | [**list_metadata_schemas**](docs/MetadataSchemasApi.md#list_metadata_schemas) | **GET** /v1/metadata-schemas | List Metadata Schemas
*OrdersApi* | [**create_order**](docs/OrdersApi.md#create_order) | **POST** /v1/orders | Create Order
*OrdersApi* | [**create_order_export**](docs/OrdersApi.md#create_order_export) | **POST** /v1/orders/export | Create Orders Export
*OrdersApi* | [**get_order**](docs/OrdersApi.md#get_order) | **GET** /v1/orders/{orderId} | Get Order
*OrdersApi* | [**import_orders**](docs/OrdersApi.md#import_orders) | **POST** /v1/orders/import | Import Orders
*OrdersApi* | [**list_orders**](docs/OrdersApi.md#list_orders) | **GET** /v1/orders | List Orders
*OrdersApi* | [**update_order**](docs/OrdersApi.md#update_order) | **PUT** /v1/orders/{orderId} | Update Order
*ProductCollectionsApi* | [**create_product_collection**](docs/ProductCollectionsApi.md#create_product_collection) | **POST** /v1/product-collections | Create Product Collection
*ProductCollectionsApi* | [**delete_product_collection**](docs/ProductCollectionsApi.md#delete_product_collection) | **DELETE** /v1/product-collections/{productCollectionId} | Delete Product Collection
*ProductCollectionsApi* | [**get_product_collection**](docs/ProductCollectionsApi.md#get_product_collection) | **GET** /v1/product-collections/{productCollectionId} | Get Product Collection
*ProductCollectionsApi* | [**list_product_collections**](docs/ProductCollectionsApi.md#list_product_collections) | **GET** /v1/product-collections | List Product Collections
*ProductCollectionsApi* | [**list_products_in_collection**](docs/ProductCollectionsApi.md#list_products_in_collection) | **GET** /v1/product-collections/{productCollectionId}/products | List Products in Collection
*ProductsApi* | [**create_product**](docs/ProductsApi.md#create_product) | **POST** /v1/products | Create Product
*ProductsApi* | [**create_sku**](docs/ProductsApi.md#create_sku) | **POST** /v1/products/{productId}/skus | Create SKU
*ProductsApi* | [**delete_product**](docs/ProductsApi.md#delete_product) | **DELETE** /v1/products/{productId} | Delete Product
*ProductsApi* | [**delete_sku**](docs/ProductsApi.md#delete_sku) | **DELETE** /v1/products/{productId}/skus/{skuId} | Delete SKU
*ProductsApi* | [**get_product**](docs/ProductsApi.md#get_product) | **GET** /v1/products/{productId} | Get Product
*ProductsApi* | [**get_sku**](docs/ProductsApi.md#get_sku) | **GET** /v1/skus/{skuId} | Get SKU
*ProductsApi* | [**import_products_using_csv**](docs/ProductsApi.md#import_products_using_csv) | **POST** /v1/products/importCSV | Import Products using CSV
*ProductsApi* | [**import_skus_using_csv**](docs/ProductsApi.md#import_skus_using_csv) | **POST** /v1/skus/importCSV | Import SKUs using CSV
*ProductsApi* | [**list_products**](docs/ProductsApi.md#list_products) | **GET** /v1/products | List Products
*ProductsApi* | [**list_skus_in_product**](docs/ProductsApi.md#list_skus_in_product) | **GET** /v1/products/{productId}/skus | List SKUs in Product
*ProductsApi* | [**update_product**](docs/ProductsApi.md#update_product) | **PUT** /v1/products/{productId} | Update Product
*ProductsApi* | [**update_products_in_bulk**](docs/ProductsApi.md#update_products_in_bulk) | **POST** /v1/products/bulk/async | Update Products in Bulk
*ProductsApi* | [**update_products_metadata_in_bulk**](docs/ProductsApi.md#update_products_metadata_in_bulk) | **POST** /v1/products/metadata/async | Update Products&#39; Metadata in Bulk
*ProductsApi* | [**update_sku**](docs/ProductsApi.md#update_sku) | **PUT** /v1/products/{productId}/skus/{skuId} | Update SKU
*PromotionsApi* | [**add_promotion_tier_to_campaign**](docs/PromotionsApi.md#add_promotion_tier_to_campaign) | **POST** /v1/promotions/{campaignId}/tiers | Add Promotion Tier to Campaign
*PromotionsApi* | [**create_promotion_stack**](docs/PromotionsApi.md#create_promotion_stack) | **POST** /v1/promotions/{campaignId}/stacks | Create Promotion Stack
*PromotionsApi* | [**delete_promotion_stack**](docs/PromotionsApi.md#delete_promotion_stack) | **DELETE** /v1/promotions/{campaignId}/stacks/{stackId} | Delete Promotion Stack
*PromotionsApi* | [**delete_promotion_tier**](docs/PromotionsApi.md#delete_promotion_tier) | **DELETE** /v1/promotions/tiers/{promotionTierId} | Delete Promotion Tier
*PromotionsApi* | [**disable_promotion_tier**](docs/PromotionsApi.md#disable_promotion_tier) | **POST** /v1/promotions/tiers/{promotionTierId}/disable | Disable Promotion Tier
*PromotionsApi* | [**enable_promotion_tier**](docs/PromotionsApi.md#enable_promotion_tier) | **POST** /v1/promotions/tiers/{promotionTierId}/enable | Enable Promotion Tier
*PromotionsApi* | [**get_promotion_stack**](docs/PromotionsApi.md#get_promotion_stack) | **GET** /v1/promotions/{campaignId}/stacks/{stackId} | Get Promotion Stack
*PromotionsApi* | [**get_promotion_tier**](docs/PromotionsApi.md#get_promotion_tier) | **GET** /v1/promotions/tiers/{promotionTierId} | Get Promotion Tier
*PromotionsApi* | [**list_all_promotion_stacks**](docs/PromotionsApi.md#list_all_promotion_stacks) | **GET** /v1/promotions/stacks | List Promotion Stacks
*PromotionsApi* | [**list_promotion_stacks_in_campaign**](docs/PromotionsApi.md#list_promotion_stacks_in_campaign) | **GET** /v1/promotions/{campaignId}/stacks | List Promotion Stacks in Campaign
*PromotionsApi* | [**list_promotion_tiers**](docs/PromotionsApi.md#list_promotion_tiers) | **GET** /v1/promotions/tiers | List Promotion Tiers
*PromotionsApi* | [**list_promotion_tiers_from_campaign**](docs/PromotionsApi.md#list_promotion_tiers_from_campaign) | **GET** /v1/promotions/{campaignId}/tiers | List Promotion Tiers from Campaign
*PromotionsApi* | [**update_promotion_stack**](docs/PromotionsApi.md#update_promotion_stack) | **PUT** /v1/promotions/{campaignId}/stacks/{stackId} | Update Promotion Stack
*PromotionsApi* | [**update_promotion_tier**](docs/PromotionsApi.md#update_promotion_tier) | **PUT** /v1/promotions/tiers/{promotionTierId} | Update Promotion Tier
*PublicationsApi* | [**create_publication**](docs/PublicationsApi.md#create_publication) | **POST** /v1/publications | Create Publication
*PublicationsApi* | [**create_publication1**](docs/PublicationsApi.md#create_publication1) | **GET** /v1/publications/create | Create Publication
*PublicationsApi* | [**list_publications**](docs/PublicationsApi.md#list_publications) | **GET** /v1/publications | List Publications
*QualificationsApi* | [**check_eligibility**](docs/QualificationsApi.md#check_eligibility) | **POST** /v1/qualifications | Check Eligibility
*RedemptionsApi* | [**get_redemption**](docs/RedemptionsApi.md#get_redemption) | **GET** /v1/redemptions/{redemptionId} | Get Redemption
*RedemptionsApi* | [**get_voucher_redemptions**](docs/RedemptionsApi.md#get_voucher_redemptions) | **GET** /v1/vouchers/{code}/redemption | Get Voucher&#39;s Redemptions
*RedemptionsApi* | [**list_redemptions**](docs/RedemptionsApi.md#list_redemptions) | **GET** /v1/redemptions | List Redemptions
*RedemptionsApi* | [**redeem_stacked_discounts**](docs/RedemptionsApi.md#redeem_stacked_discounts) | **POST** /v1/redemptions | Redeem Stackable Discounts
*RedemptionsApi* | [**rollback_redemption**](docs/RedemptionsApi.md#rollback_redemption) | **POST** /v1/redemptions/{redemptionId}/rollback | Rollback Redemption
*RedemptionsApi* | [**rollback_stacked_redemptions**](docs/RedemptionsApi.md#rollback_stacked_redemptions) | **POST** /v1/redemptions/{parentRedemptionId}/rollbacks | Rollback Stackable Redemptions
*ReferralsApi* | [**referrals_add_holders**](docs/ReferralsApi.md#referrals_add_holders) | **POST** /v1/referrals/members/{memberId}/holders | Add Referral Code Holders
*ReferralsApi* | [**referrals_add_holders1**](docs/ReferralsApi.md#referrals_add_holders1) | **POST** /v1/referrals/{campaignId}/members/{memberId}/holders | Add Referral Code Holders
*ReferralsApi* | [**referrals_code_holders**](docs/ReferralsApi.md#referrals_code_holders) | **GET** /v1/referrals/{campaignId}/members/{memberId}/holders | List Referral Code Holders
*ReferralsApi* | [**referrals_code_holders1**](docs/ReferralsApi.md#referrals_code_holders1) | **GET** /v1/referrals/members/{memberId}/holders | List Referral Code Holders
*ReferralsApi* | [**referrals_remove_holder**](docs/ReferralsApi.md#referrals_remove_holder) | **DELETE** /v1/referrals/members/{memberId}/holders/{holderId} | Remove Referral Card Holder
*ReferralsApi* | [**referrals_remove_holder1**](docs/ReferralsApi.md#referrals_remove_holder1) | **DELETE** /v1/referrals/{campaignId}/members/{memberId}/holders/{holderId} | Remove Referral Card Holder
*RewardsApi* | [**create_reward**](docs/RewardsApi.md#create_reward) | **POST** /v1/rewards | Create Reward
*RewardsApi* | [**create_reward_assignment**](docs/RewardsApi.md#create_reward_assignment) | **POST** /v1/rewards/{rewardId}/assignments | Create Reward Assignment
*RewardsApi* | [**delete_reward**](docs/RewardsApi.md#delete_reward) | **DELETE** /v1/rewards/{rewardId} | Delete Reward
*RewardsApi* | [**delete_reward_assignment**](docs/RewardsApi.md#delete_reward_assignment) | **DELETE** /v1/rewards/{rewardId}/assignments/{assignmentId} | Delete Reward Assignment
*RewardsApi* | [**get_reward**](docs/RewardsApi.md#get_reward) | **GET** /v1/rewards/{rewardId} | Get Reward
*RewardsApi* | [**get_reward_assignment**](docs/RewardsApi.md#get_reward_assignment) | **GET** /v1/rewards/{rewardId}/assignments/{assignmentId} | Get Reward Assignment
*RewardsApi* | [**list_reward_assignments**](docs/RewardsApi.md#list_reward_assignments) | **GET** /v1/rewards/{rewardId}/assignments | List Reward Assignments
*RewardsApi* | [**list_rewards**](docs/RewardsApi.md#list_rewards) | **GET** /v1/rewards | List Rewards
*RewardsApi* | [**update_reward**](docs/RewardsApi.md#update_reward) | **PUT** /v1/rewards/{rewardId} | Update Reward
*RewardsApi* | [**update_reward_assignment**](docs/RewardsApi.md#update_reward_assignment) | **PUT** /v1/rewards/{rewardId}/assignments/{assignmentId} | Update Reward Assignment
*SegmentsApi* | [**create_segment**](docs/SegmentsApi.md#create_segment) | **POST** /v1/segments | Create Segment
*SegmentsApi* | [**delete_segment**](docs/SegmentsApi.md#delete_segment) | **DELETE** /v1/segments/{segmentId} | Delete Segment
*SegmentsApi* | [**get_segment**](docs/SegmentsApi.md#get_segment) | **GET** /v1/segments/{segmentId} | Get Segment
*TemplatesApi* | [**add_tier_from_template**](docs/TemplatesApi.md#add_tier_from_template) | **POST** /v1/templates/campaigns/{campaignTemplateId}/tier-setup | Add Promotion Tier From Template
*TemplatesApi* | [**create_campaign_from_template**](docs/TemplatesApi.md#create_campaign_from_template) | **POST** /v1/templates/campaigns/{campaignTemplateId}/campaign-setup | Create Campaign From Template
*TemplatesApi* | [**create_campaign_template**](docs/TemplatesApi.md#create_campaign_template) | **POST** /v1/templates/campaigns | Create Campaign Template
*TemplatesApi* | [**delete_campaign_template**](docs/TemplatesApi.md#delete_campaign_template) | **DELETE** /v1/templates/campaigns/{campaignTemplateId} | Delete Campaign Template
*TemplatesApi* | [**get_campaign_template**](docs/TemplatesApi.md#get_campaign_template) | **GET** /v1/templates/campaigns/{campaignTemplateId} | Get Campaign Template
*TemplatesApi* | [**list_campaign_templates**](docs/TemplatesApi.md#list_campaign_templates) | **GET** /v1/templates/campaigns | List Campaign Templates
*TemplatesApi* | [**update_campaign_template**](docs/TemplatesApi.md#update_campaign_template) | **PUT** /v1/templates/campaigns/{campaignTemplateId} | Update Campaign Template
*ValidationRulesApi* | [**create_validation_rule_assignment**](docs/ValidationRulesApi.md#create_validation_rule_assignment) | **POST** /v1/validation-rules/{validationRuleId}/assignments | Create Validation Rules Assignments
*ValidationRulesApi* | [**create_validation_rules**](docs/ValidationRulesApi.md#create_validation_rules) | **POST** /v1/validation-rules | Create Validation Rules
*ValidationRulesApi* | [**delete_validation_rule_assignment**](docs/ValidationRulesApi.md#delete_validation_rule_assignment) | **DELETE** /v1/validation-rules/{validationRuleId}/assignments/{assignmentId} | Delete Validation Rule Assignment
*ValidationRulesApi* | [**delete_validation_rules**](docs/ValidationRulesApi.md#delete_validation_rules) | **DELETE** /v1/validation-rules/{validationRuleId} | Delete Validation Rule
*ValidationRulesApi* | [**get_validation_rule**](docs/ValidationRulesApi.md#get_validation_rule) | **GET** /v1/validation-rules/{validationRuleId} | Get Validation Rule
*ValidationRulesApi* | [**list_validation_rule_assignments**](docs/ValidationRulesApi.md#list_validation_rule_assignments) | **GET** /v1/validation-rules/{validationRuleId}/assignments | List Validation Rule Assignments
*ValidationRulesApi* | [**list_validation_rules**](docs/ValidationRulesApi.md#list_validation_rules) | **GET** /v1/validation-rules | List Validation Rules
*ValidationRulesApi* | [**list_validation_rules_assignments**](docs/ValidationRulesApi.md#list_validation_rules_assignments) | **GET** /v1/validation-rules-assignments | List Validation Rules&#39; Assignment(s)
*ValidationRulesApi* | [**update_validation_rule**](docs/ValidationRulesApi.md#update_validation_rule) | **PUT** /v1/validation-rules/{validationRuleId} | Update Validation Rule
*ValidationsApi* | [**validate_stacked_discounts**](docs/ValidationsApi.md#validate_stacked_discounts) | **POST** /v1/validations | Validate Stackable Discounts
*VouchersApi* | [**create_voucher**](docs/VouchersApi.md#create_voucher) | **POST** /v1/vouchers/{code} | Create Voucher
*VouchersApi* | [**delete_voucher**](docs/VouchersApi.md#delete_voucher) | **DELETE** /v1/vouchers/{code} | Delete Voucher
*VouchersApi* | [**disable_voucher**](docs/VouchersApi.md#disable_voucher) | **POST** /v1/vouchers/{code}/disable | Disable Voucher
*VouchersApi* | [**enable_voucher**](docs/VouchersApi.md#enable_voucher) | **POST** /v1/vouchers/{code}/enable | Enable Voucher
*VouchersApi* | [**export_voucher_transactions**](docs/VouchersApi.md#export_voucher_transactions) | **POST** /v1/vouchers/{code}/transactions/export | Export Voucher Transactions
*VouchersApi* | [**generate_random_code**](docs/VouchersApi.md#generate_random_code) | **POST** /v1/vouchers | Generate Random Code
*VouchersApi* | [**get_voucher**](docs/VouchersApi.md#get_voucher) | **GET** /v1/vouchers/{code} | Get Voucher
*VouchersApi* | [**import_vouchers**](docs/VouchersApi.md#import_vouchers) | **POST** /v1/vouchers/import | Import Vouchers
*VouchersApi* | [**import_vouchers_using_csv**](docs/VouchersApi.md#import_vouchers_using_csv) | **POST** /v1/vouchers/importCSV | Import Vouchers using CSV
*VouchersApi* | [**list_voucher_transactions**](docs/VouchersApi.md#list_voucher_transactions) | **GET** /v1/vouchers/{code}/transactions | List Voucher Transactions
*VouchersApi* | [**list_vouchers**](docs/VouchersApi.md#list_vouchers) | **GET** /v1/vouchers | List Vouchers
*VouchersApi* | [**release_validation_session**](docs/VouchersApi.md#release_validation_session) | **DELETE** /v1/vouchers/{code}/sessions/{sessionKey} | Release Validation Session
*VouchersApi* | [**update_voucher**](docs/VouchersApi.md#update_voucher) | **PUT** /v1/vouchers/{code} | Update Voucher
*VouchersApi* | [**update_voucher_balance**](docs/VouchersApi.md#update_voucher_balance) | **POST** /v1/vouchers/{code}/balance | Add or Remove Voucher Balance
*VouchersApi* | [**update_vouchers_in_bulk**](docs/VouchersApi.md#update_vouchers_in_bulk) | **POST** /v1/vouchers/bulk/async | Update Vouchers in Bulk
*VouchersApi* | [**update_vouchers_metadata_in_bulk**](docs/VouchersApi.md#update_vouchers_metadata_in_bulk) | **POST** /v1/vouchers/metadata/async | Update Vouchers&#39; Metadata in Bulk


## Documentation For Models

 - [AccessSettingsCampaignAssignmentsList](docs/AccessSettingsCampaignAssignmentsList.md)
 - [ApplicableTo](docs/ApplicableTo.md)
 - [ApplicableToEffect](docs/ApplicableToEffect.md)
 - [ApplicableToResultList](docs/ApplicableToResultList.md)
 - [AreaStoreCampaignAssignment](docs/AreaStoreCampaignAssignment.md)
 - [AsyncActionBase](docs/AsyncActionBase.md)
 - [AsyncActionGetResponseBody](docs/AsyncActionGetResponseBody.md)
 - [AsyncActionsListResponseBody](docs/AsyncActionsListResponseBody.md)
 - [BusValRuleAssignment](docs/BusValRuleAssignment.md)
 - [Campaign](docs/Campaign.md)
 - [CampaignBase](docs/CampaignBase.md)
 - [CampaignLoyaltyCard](docs/CampaignLoyaltyCard.md)
 - [CampaignLoyaltyCardExpirationRules](docs/CampaignLoyaltyCardExpirationRules.md)
 - [CampaignLoyaltyVoucher](docs/CampaignLoyaltyVoucher.md)
 - [CampaignLoyaltyVoucherRedemption](docs/CampaignLoyaltyVoucherRedemption.md)
 - [CampaignTemplate](docs/CampaignTemplate.md)
 - [CampaignVoucher](docs/CampaignVoucher.md)
 - [CampaignVoucherRedemption](docs/CampaignVoucherRedemption.md)
 - [CampaignsCreateRequestBody](docs/CampaignsCreateRequestBody.md)
 - [CampaignsCreateRequestBodyPromotion](docs/CampaignsCreateRequestBodyPromotion.md)
 - [CampaignsCreateRequestBodyVoucher](docs/CampaignsCreateRequestBodyVoucher.md)
 - [CampaignsCreateRequestBodyVoucherRedemption](docs/CampaignsCreateRequestBodyVoucherRedemption.md)
 - [CampaignsCreateResponseBody](docs/CampaignsCreateResponseBody.md)
 - [CampaignsDeleteResponseBody](docs/CampaignsDeleteResponseBody.md)
 - [CampaignsGetResponseBody](docs/CampaignsGetResponseBody.md)
 - [CampaignsImportCreateResponseBody](docs/CampaignsImportCreateResponseBody.md)
 - [CampaignsImportCsvCreateResponseBody](docs/CampaignsImportCsvCreateResponseBody.md)
 - [CampaignsImportVoucherItem](docs/CampaignsImportVoucherItem.md)
 - [CampaignsImportVoucherItemRedemption](docs/CampaignsImportVoucherItemRedemption.md)
 - [CampaignsListResponseBody](docs/CampaignsListResponseBody.md)
 - [CampaignsUpdateRequestBody](docs/CampaignsUpdateRequestBody.md)
 - [CampaignsUpdateRequestBodyOptions](docs/CampaignsUpdateRequestBodyOptions.md)
 - [CampaignsUpdateResponseBody](docs/CampaignsUpdateResponseBody.md)
 - [CampaignsVouchersCreateCombinedResponseBody](docs/CampaignsVouchersCreateCombinedResponseBody.md)
 - [CampaignsVouchersCreateCombinedResponseBodyGift](docs/CampaignsVouchersCreateCombinedResponseBodyGift.md)
 - [CampaignsVouchersCreateCombinedResponseBodyLoyaltyCard](docs/CampaignsVouchersCreateCombinedResponseBodyLoyaltyCard.md)
 - [CampaignsVouchersCreateCombinedResponseBodyPublish](docs/CampaignsVouchersCreateCombinedResponseBodyPublish.md)
 - [CampaignsVouchersCreateCombinedResponseBodyRedemption](docs/CampaignsVouchersCreateCombinedResponseBodyRedemption.md)
 - [CampaignsVouchersCreateInBulkRequestBody](docs/CampaignsVouchersCreateInBulkRequestBody.md)
 - [CampaignsVouchersCreateInBulkRequestBodyRedemption](docs/CampaignsVouchersCreateInBulkRequestBodyRedemption.md)
 - [CampaignsVouchersCreateRequestBody](docs/CampaignsVouchersCreateRequestBody.md)
 - [CampaignsVouchersCreateRequestBodyRedemption](docs/CampaignsVouchersCreateRequestBodyRedemption.md)
 - [CampaignsVouchersCreateResponseBody](docs/CampaignsVouchersCreateResponseBody.md)
 - [CampaignsVouchersCreateResponseBodyGift](docs/CampaignsVouchersCreateResponseBodyGift.md)
 - [CampaignsVouchersCreateResponseBodyLoyaltyCard](docs/CampaignsVouchersCreateResponseBodyLoyaltyCard.md)
 - [CampaignsVouchersCreateResponseBodyPublish](docs/CampaignsVouchersCreateResponseBodyPublish.md)
 - [CampaignsVouchersCreateResponseBodyRedemption](docs/CampaignsVouchersCreateResponseBodyRedemption.md)
 - [CategoriesCreateRequestBody](docs/CategoriesCreateRequestBody.md)
 - [CategoriesCreateResponseBody](docs/CategoriesCreateResponseBody.md)
 - [CategoriesGetResponseBody](docs/CategoriesGetResponseBody.md)
 - [CategoriesListResponseBody](docs/CategoriesListResponseBody.md)
 - [CategoriesUpdateRequestBody](docs/CategoriesUpdateRequestBody.md)
 - [CategoriesUpdateResponseBody](docs/CategoriesUpdateResponseBody.md)
 - [Category](docs/Category.md)
 - [CategoryWithStackingRulesType](docs/CategoryWithStackingRulesType.md)
 - [ClientEventsCreateRequestBody](docs/ClientEventsCreateRequestBody.md)
 - [ClientEventsCreateRequestBodyLoyalty](docs/ClientEventsCreateRequestBodyLoyalty.md)
 - [ClientEventsCreateRequestBodyReferral](docs/ClientEventsCreateRequestBodyReferral.md)
 - [ClientEventsCreateResponseBody](docs/ClientEventsCreateResponseBody.md)
 - [ClientPromotionsTiersListResponseBody](docs/ClientPromotionsTiersListResponseBody.md)
 - [ClientQualificationsCheckEligibilityRequestBody](docs/ClientQualificationsCheckEligibilityRequestBody.md)
 - [ClientQualificationsCheckEligibilityResponseBody](docs/ClientQualificationsCheckEligibilityResponseBody.md)
 - [ClientRedemptionsRedeemRequestBody](docs/ClientRedemptionsRedeemRequestBody.md)
 - [ClientRedemptionsRedeemRequestBodyOptions](docs/ClientRedemptionsRedeemRequestBodyOptions.md)
 - [ClientRedemptionsRedeemRequestBodyRedeemablesItem](docs/ClientRedemptionsRedeemRequestBodyRedeemablesItem.md)
 - [ClientRedemptionsRedeemRequestBodyRedeemablesItemGift](docs/ClientRedemptionsRedeemRequestBodyRedeemablesItemGift.md)
 - [ClientRedemptionsRedeemRequestBodyRedeemablesItemReward](docs/ClientRedemptionsRedeemRequestBodyRedeemablesItemReward.md)
 - [ClientRedemptionsRedeemResponseBody](docs/ClientRedemptionsRedeemResponseBody.md)
 - [ClientValidationsValidateRequestBody](docs/ClientValidationsValidateRequestBody.md)
 - [ClientValidationsValidateRequestBodyOptions](docs/ClientValidationsValidateRequestBodyOptions.md)
 - [ClientValidationsValidateRequestBodyRedeemablesItem](docs/ClientValidationsValidateRequestBodyRedeemablesItem.md)
 - [ClientValidationsValidateRequestBodyRedeemablesItemGift](docs/ClientValidationsValidateRequestBodyRedeemablesItemGift.md)
 - [ClientValidationsValidateRequestBodyRedeemablesItemReward](docs/ClientValidationsValidateRequestBodyRedeemablesItemReward.md)
 - [ClientValidationsValidateResponseBody](docs/ClientValidationsValidateResponseBody.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItem](docs/ClientValidationsValidateResponseBodyRedeemablesItem.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItemResult](docs/ClientValidationsValidateResponseBodyRedeemablesItemResult.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItemResultDetails](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultDetails.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItemResultDiscount](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultDiscount.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItemResultGift](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultGift.md)
 - [ClientValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard](docs/ClientValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard.md)
 - [CodeConfig](docs/CodeConfig.md)
 - [CreatePublicationCampaign](docs/CreatePublicationCampaign.md)
 - [Customer](docs/Customer.md)
 - [CustomerActivity](docs/CustomerActivity.md)
 - [CustomerAddress](docs/CustomerAddress.md)
 - [CustomerId](docs/CustomerId.md)
 - [CustomerLoyalty](docs/CustomerLoyalty.md)
 - [CustomerRedeemable](docs/CustomerRedeemable.md)
 - [CustomerRedeemableRedeemable](docs/CustomerRedeemableRedeemable.md)
 - [CustomerReferrals](docs/CustomerReferrals.md)
 - [CustomerReferralsCampaignsItem](docs/CustomerReferralsCampaignsItem.md)
 - [CustomerSummary](docs/CustomerSummary.md)
 - [CustomerSummaryOrders](docs/CustomerSummaryOrders.md)
 - [CustomerSummaryRedemptions](docs/CustomerSummaryRedemptions.md)
 - [CustomerSummaryRedemptionsGift](docs/CustomerSummaryRedemptionsGift.md)
 - [CustomerSummaryRedemptionsLoyaltyCard](docs/CustomerSummaryRedemptionsLoyaltyCard.md)
 - [CustomerWithSummaryLoyaltyReferrals](docs/CustomerWithSummaryLoyaltyReferrals.md)
 - [CustomerWithSummaryLoyaltyReferralsAddress](docs/CustomerWithSummaryLoyaltyReferralsAddress.md)
 - [CustomerWithSummaryLoyaltyReferralsAssets](docs/CustomerWithSummaryLoyaltyReferralsAssets.md)
 - [CustomersActivityListResponseBody](docs/CustomersActivityListResponseBody.md)
 - [CustomersCreateRequestBody](docs/CustomersCreateRequestBody.md)
 - [CustomersCreateRequestBodyAddress](docs/CustomersCreateRequestBodyAddress.md)
 - [CustomersCreateResponseBody](docs/CustomersCreateResponseBody.md)
 - [CustomersCreateResponseBodyAddress](docs/CustomersCreateResponseBodyAddress.md)
 - [CustomersCreateResponseBodyAssets](docs/CustomersCreateResponseBodyAssets.md)
 - [CustomersGetResponseBody](docs/CustomersGetResponseBody.md)
 - [CustomersGetResponseBodyAddress](docs/CustomersGetResponseBodyAddress.md)
 - [CustomersGetResponseBodyAssets](docs/CustomersGetResponseBodyAssets.md)
 - [CustomersImportCsvCreateResponseBody](docs/CustomersImportCsvCreateResponseBody.md)
 - [CustomersListResponseBody](docs/CustomersListResponseBody.md)
 - [CustomersMetadataUpdateInBulkRequestBody](docs/CustomersMetadataUpdateInBulkRequestBody.md)
 - [CustomersMetadataUpdateInBulkResponseBody](docs/CustomersMetadataUpdateInBulkResponseBody.md)
 - [CustomersPermanentDeletionCreateResponseBody](docs/CustomersPermanentDeletionCreateResponseBody.md)
 - [CustomersPermanentDeletionCreateResponseBodyDataJson](docs/CustomersPermanentDeletionCreateResponseBodyDataJson.md)
 - [CustomersRedeemablesListResponseBody](docs/CustomersRedeemablesListResponseBody.md)
 - [CustomersSegmentsListResponseBody](docs/CustomersSegmentsListResponseBody.md)
 - [CustomersUpdateInBulkRequestBody](docs/CustomersUpdateInBulkRequestBody.md)
 - [CustomersUpdateInBulkRequestBodyAddress](docs/CustomersUpdateInBulkRequestBodyAddress.md)
 - [CustomersUpdateInBulkResponseBody](docs/CustomersUpdateInBulkResponseBody.md)
 - [CustomersUpdateRequestBody](docs/CustomersUpdateRequestBody.md)
 - [CustomersUpdateRequestBodyAddress](docs/CustomersUpdateRequestBodyAddress.md)
 - [CustomersUpdateResponseBody](docs/CustomersUpdateResponseBody.md)
 - [CustomersUpdateResponseBodyAddress](docs/CustomersUpdateResponseBodyAddress.md)
 - [CustomersUpdateResponseBodyAssets](docs/CustomersUpdateResponseBodyAssets.md)
 - [Discount](docs/Discount.md)
 - [DiscountProduct](docs/DiscountProduct.md)
 - [DiscountUnitMultipleOneUnit](docs/DiscountUnitMultipleOneUnit.md)
 - [EarningRule](docs/EarningRule.md)
 - [EarningRuleCustomEvent](docs/EarningRuleCustomEvent.md)
 - [EarningRuleLoyalty](docs/EarningRuleLoyalty.md)
 - [EarningRuleLoyaltyCustomEvent](docs/EarningRuleLoyaltyCustomEvent.md)
 - [EarningRuleLoyaltyCustomEventMetadata](docs/EarningRuleLoyaltyCustomEventMetadata.md)
 - [EarningRuleLoyaltyCustomer](docs/EarningRuleLoyaltyCustomer.md)
 - [EarningRuleLoyaltyCustomerMetadata](docs/EarningRuleLoyaltyCustomerMetadata.md)
 - [EarningRuleLoyaltyOrder](docs/EarningRuleLoyaltyOrder.md)
 - [EarningRuleLoyaltyOrderAmount](docs/EarningRuleLoyaltyOrderAmount.md)
 - [EarningRuleLoyaltyOrderItems](docs/EarningRuleLoyaltyOrderItems.md)
 - [EarningRuleLoyaltyOrderItemsAmount](docs/EarningRuleLoyaltyOrderItemsAmount.md)
 - [EarningRuleLoyaltyOrderItemsQuantity](docs/EarningRuleLoyaltyOrderItemsQuantity.md)
 - [EarningRuleLoyaltyOrderItemsSubtotalAmount](docs/EarningRuleLoyaltyOrderItemsSubtotalAmount.md)
 - [EarningRuleLoyaltyOrderMetadata](docs/EarningRuleLoyaltyOrderMetadata.md)
 - [EarningRuleLoyaltyOrderTotalAmount](docs/EarningRuleLoyaltyOrderTotalAmount.md)
 - [EarningRuleLoyaltyTier](docs/EarningRuleLoyaltyTier.md)
 - [EarningRuleSegment](docs/EarningRuleSegment.md)
 - [EarningRuleSource](docs/EarningRuleSource.md)
 - [Error](docs/Error.md)
 - [ErrorError](docs/ErrorError.md)
 - [EventsCreateRequestBody](docs/EventsCreateRequestBody.md)
 - [EventsCreateRequestBodyLoyalty](docs/EventsCreateRequestBodyLoyalty.md)
 - [EventsCreateRequestBodyReferral](docs/EventsCreateRequestBodyReferral.md)
 - [EventsCreateResponseBody](docs/EventsCreateResponseBody.md)
 - [Export](docs/Export.md)
 - [ExportOrderFields](docs/ExportOrderFields.md)
 - [ExportOrderOrder](docs/ExportOrderOrder.md)
 - [ExportParameters](docs/ExportParameters.md)
 - [ExportResult](docs/ExportResult.md)
 - [ExportVoucherTransactionsFields](docs/ExportVoucherTransactionsFields.md)
 - [ExportVoucherTransactionsFilters](docs/ExportVoucherTransactionsFilters.md)
 - [ExportVoucherTransactionsOrder](docs/ExportVoucherTransactionsOrder.md)
 - [ExportsCreateRequestBody](docs/ExportsCreateRequestBody.md)
 - [ExportsCreateRequestBodyParameters](docs/ExportsCreateRequestBodyParameters.md)
 - [ExportsCreateResponseBody](docs/ExportsCreateResponseBody.md)
 - [ExportsCreateResponseBodyParameters](docs/ExportsCreateResponseBodyParameters.md)
 - [ExportsGetResponseBody](docs/ExportsGetResponseBody.md)
 - [ExportsGetResponseBodyParameters](docs/ExportsGetResponseBodyParameters.md)
 - [ExportsGetResponseBodyResult](docs/ExportsGetResponseBodyResult.md)
 - [ExportsListResponseBody](docs/ExportsListResponseBody.md)
 - [FieldConditions](docs/FieldConditions.md)
 - [FilterConditionsDateTime](docs/FilterConditionsDateTime.md)
 - [FilterConditionsString](docs/FilterConditionsString.md)
 - [FiltersCondition](docs/FiltersCondition.md)
 - [Gift](docs/Gift.md)
 - [InapplicableTo](docs/InapplicableTo.md)
 - [InapplicableToResultList](docs/InapplicableToResultList.md)
 - [Junction](docs/Junction.md)
 - [ListPublicationsItemVoucher](docs/ListPublicationsItemVoucher.md)
 - [Location](docs/Location.md)
 - [LocationShape](docs/LocationShape.md)
 - [LocationShapeDistance](docs/LocationShapeDistance.md)
 - [LocationShapeGeojson](docs/LocationShapeGeojson.md)
 - [LocationsGetResponseBody](docs/LocationsGetResponseBody.md)
 - [LocationsGetResponseBodyShape](docs/LocationsGetResponseBodyShape.md)
 - [LocationsGetResponseBodyShapeDistance](docs/LocationsGetResponseBodyShapeDistance.md)
 - [LocationsGetResponseBodyShapeGeojson](docs/LocationsGetResponseBodyShapeGeojson.md)
 - [LocationsListResponseBody](docs/LocationsListResponseBody.md)
 - [LoyaltiesCreateCampaignRequestBody](docs/LoyaltiesCreateCampaignRequestBody.md)
 - [LoyaltiesCreateCampaignResponseBody](docs/LoyaltiesCreateCampaignResponseBody.md)
 - [LoyaltiesDeleteResponseBody](docs/LoyaltiesDeleteResponseBody.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItem](docs/LoyaltiesEarningRulesCreateRequestBodyItem.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemCustomEvent](docs/LoyaltiesEarningRulesCreateRequestBodyItemCustomEvent.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyalty](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyalty.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEvent](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomer](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrder](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrder.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItems](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyTier](docs/LoyaltiesEarningRulesCreateRequestBodyItemLoyaltyTier.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemSegment](docs/LoyaltiesEarningRulesCreateRequestBodyItemSegment.md)
 - [LoyaltiesEarningRulesCreateRequestBodyItemSource](docs/LoyaltiesEarningRulesCreateRequestBodyItemSource.md)
 - [LoyaltiesEarningRulesCreateResponseBody](docs/LoyaltiesEarningRulesCreateResponseBody.md)
 - [LoyaltiesEarningRulesCreateResponseBodyCustomEvent](docs/LoyaltiesEarningRulesCreateResponseBodyCustomEvent.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyalty](docs/LoyaltiesEarningRulesCreateResponseBodyLoyalty.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrder.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesCreateResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesCreateResponseBodyLoyaltyTier.md)
 - [LoyaltiesEarningRulesCreateResponseBodySegment](docs/LoyaltiesEarningRulesCreateResponseBodySegment.md)
 - [LoyaltiesEarningRulesCreateResponseBodySource](docs/LoyaltiesEarningRulesCreateResponseBodySource.md)
 - [LoyaltiesEarningRulesDisableResponseBody](docs/LoyaltiesEarningRulesDisableResponseBody.md)
 - [LoyaltiesEarningRulesDisableResponseBodyCustomEvent](docs/LoyaltiesEarningRulesDisableResponseBodyCustomEvent.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyalty](docs/LoyaltiesEarningRulesDisableResponseBodyLoyalty.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrder.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesDisableResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesDisableResponseBodyLoyaltyTier.md)
 - [LoyaltiesEarningRulesDisableResponseBodySegment](docs/LoyaltiesEarningRulesDisableResponseBodySegment.md)
 - [LoyaltiesEarningRulesDisableResponseBodySource](docs/LoyaltiesEarningRulesDisableResponseBodySource.md)
 - [LoyaltiesEarningRulesEnableResponseBody](docs/LoyaltiesEarningRulesEnableResponseBody.md)
 - [LoyaltiesEarningRulesEnableResponseBodyCustomEvent](docs/LoyaltiesEarningRulesEnableResponseBodyCustomEvent.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyalty](docs/LoyaltiesEarningRulesEnableResponseBodyLoyalty.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrder.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesEnableResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesEnableResponseBodyLoyaltyTier.md)
 - [LoyaltiesEarningRulesEnableResponseBodySegment](docs/LoyaltiesEarningRulesEnableResponseBodySegment.md)
 - [LoyaltiesEarningRulesEnableResponseBodySource](docs/LoyaltiesEarningRulesEnableResponseBodySource.md)
 - [LoyaltiesEarningRulesGetResponseBody](docs/LoyaltiesEarningRulesGetResponseBody.md)
 - [LoyaltiesEarningRulesGetResponseBodyCustomEvent](docs/LoyaltiesEarningRulesGetResponseBodyCustomEvent.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyalty](docs/LoyaltiesEarningRulesGetResponseBodyLoyalty.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrder.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesGetResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesGetResponseBodyLoyaltyTier.md)
 - [LoyaltiesEarningRulesGetResponseBodySegment](docs/LoyaltiesEarningRulesGetResponseBodySegment.md)
 - [LoyaltiesEarningRulesGetResponseBodySource](docs/LoyaltiesEarningRulesGetResponseBodySource.md)
 - [LoyaltiesEarningRulesListResponseBody](docs/LoyaltiesEarningRulesListResponseBody.md)
 - [LoyaltiesEarningRulesUpdateRequestBody](docs/LoyaltiesEarningRulesUpdateRequestBody.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyalty](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyalty.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrder](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrder.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesUpdateRequestBodyLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesUpdateRequestBodySource](docs/LoyaltiesEarningRulesUpdateRequestBodySource.md)
 - [LoyaltiesEarningRulesUpdateResponseBody](docs/LoyaltiesEarningRulesUpdateResponseBody.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyCustomEvent](docs/LoyaltiesEarningRulesUpdateResponseBodyCustomEvent.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyalty](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyalty.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEvent](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEvent.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEventMetadata](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomEventMetadata.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomer](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomer.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomerMetadata](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyCustomerMetadata.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrder](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrder.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderAmount.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItems](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItems.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsAmount.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsQuantity](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsQuantity.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsSubtotalAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderItemsSubtotalAmount.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderMetadata](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderMetadata.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderTotalAmount](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyOrderTotalAmount.md)
 - [LoyaltiesEarningRulesUpdateResponseBodyLoyaltyTier](docs/LoyaltiesEarningRulesUpdateResponseBodyLoyaltyTier.md)
 - [LoyaltiesEarningRulesUpdateResponseBodySegment](docs/LoyaltiesEarningRulesUpdateResponseBodySegment.md)
 - [LoyaltiesEarningRulesUpdateResponseBodySource](docs/LoyaltiesEarningRulesUpdateResponseBodySource.md)
 - [LoyaltiesGetCampaignResponseBody](docs/LoyaltiesGetCampaignResponseBody.md)
 - [LoyaltiesListCampaignsResponseBody](docs/LoyaltiesListCampaignsResponseBody.md)
 - [LoyaltiesListMembersResponseBody](docs/LoyaltiesListMembersResponseBody.md)
 - [LoyaltiesLoyaltyTierReward](docs/LoyaltiesLoyaltyTierReward.md)
 - [LoyaltiesMemberActivityListResponseBody](docs/LoyaltiesMemberActivityListResponseBody.md)
 - [LoyaltiesMembersBalanceUpdateRequestBody](docs/LoyaltiesMembersBalanceUpdateRequestBody.md)
 - [LoyaltiesMembersBalanceUpdateResponseBody](docs/LoyaltiesMembersBalanceUpdateResponseBody.md)
 - [LoyaltiesMembersBalanceUpdateResponseBodyRelatedObject](docs/LoyaltiesMembersBalanceUpdateResponseBodyRelatedObject.md)
 - [LoyaltiesMembersCreateRequestBody](docs/LoyaltiesMembersCreateRequestBody.md)
 - [LoyaltiesMembersCreateResponseBody](docs/LoyaltiesMembersCreateResponseBody.md)
 - [LoyaltiesMembersCreateResponseBodyLoyaltyCard](docs/LoyaltiesMembersCreateResponseBodyLoyaltyCard.md)
 - [LoyaltiesMembersCreateResponseBodyPublish](docs/LoyaltiesMembersCreateResponseBodyPublish.md)
 - [LoyaltiesMembersCreateResponseBodyRedemption](docs/LoyaltiesMembersCreateResponseBodyRedemption.md)
 - [LoyaltiesMembersGetResponseBody](docs/LoyaltiesMembersGetResponseBody.md)
 - [LoyaltiesMembersGetResponseBodyLoyaltyCard](docs/LoyaltiesMembersGetResponseBodyLoyaltyCard.md)
 - [LoyaltiesMembersGetResponseBodyPublish](docs/LoyaltiesMembersGetResponseBodyPublish.md)
 - [LoyaltiesMembersGetResponseBodyRedemption](docs/LoyaltiesMembersGetResponseBodyRedemption.md)
 - [LoyaltiesMembersPointsExpirationListResponseBody](docs/LoyaltiesMembersPointsExpirationListResponseBody.md)
 - [LoyaltiesMembersPointsExpirationListResponseBodyDataItem](docs/LoyaltiesMembersPointsExpirationListResponseBodyDataItem.md)
 - [LoyaltiesMembersPointsExpirationListResponseBodyDataItemBucket](docs/LoyaltiesMembersPointsExpirationListResponseBodyDataItemBucket.md)
 - [LoyaltiesMembersRedemptionRedeemRequestBody](docs/LoyaltiesMembersRedemptionRedeemRequestBody.md)
 - [LoyaltiesMembersRedemptionRedeemRequestBodyReward](docs/LoyaltiesMembersRedemptionRedeemRequestBodyReward.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBody](docs/LoyaltiesMembersRedemptionRedeemResponseBody.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyChannel](docs/LoyaltiesMembersRedemptionRedeemResponseBodyChannel.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyGift](docs/LoyaltiesMembersRedemptionRedeemResponseBodyGift.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyLoyaltyCard](docs/LoyaltiesMembersRedemptionRedeemResponseBodyLoyaltyCard.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptions](docs/LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptions.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRedemptionsItem](docs/LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRedemptionsItem.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRollbacksItem](docs/LoyaltiesMembersRedemptionRedeemResponseBodyRelatedRedemptionsRollbacksItem.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyVoucher](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucher.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyVoucherGift](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherGift.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyVoucherLoyaltyCard](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherLoyaltyCard.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyVoucherPublish](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherPublish.md)
 - [LoyaltiesMembersRedemptionRedeemResponseBodyVoucherRedemption](docs/LoyaltiesMembersRedemptionRedeemResponseBodyVoucherRedemption.md)
 - [LoyaltiesMembersRewardsListResponseBody](docs/LoyaltiesMembersRewardsListResponseBody.md)
 - [LoyaltiesMembersRewardsListResponseBodyDataItem](docs/LoyaltiesMembersRewardsListResponseBodyDataItem.md)
 - [LoyaltiesMembersTiersListResponseBody](docs/LoyaltiesMembersTiersListResponseBody.md)
 - [LoyaltiesMembersTransactionsExportCreateRequestBody](docs/LoyaltiesMembersTransactionsExportCreateRequestBody.md)
 - [LoyaltiesMembersTransactionsExportCreateRequestBodyParameters](docs/LoyaltiesMembersTransactionsExportCreateRequestBodyParameters.md)
 - [LoyaltiesMembersTransactionsExportCreateResponseBody](docs/LoyaltiesMembersTransactionsExportCreateResponseBody.md)
 - [LoyaltiesMembersTransactionsExportCreateResponseBodyParameters](docs/LoyaltiesMembersTransactionsExportCreateResponseBodyParameters.md)
 - [LoyaltiesMembersTransactionsListResponseBody](docs/LoyaltiesMembersTransactionsListResponseBody.md)
 - [LoyaltiesMembersTransfersCreateResponseBody](docs/LoyaltiesMembersTransfersCreateResponseBody.md)
 - [LoyaltiesMembersTransfersCreateResponseBodyAssets](docs/LoyaltiesMembersTransfersCreateResponseBodyAssets.md)
 - [LoyaltiesMembersTransfersCreateResponseBodyAssetsBarcode](docs/LoyaltiesMembersTransfersCreateResponseBodyAssetsBarcode.md)
 - [LoyaltiesMembersTransfersCreateResponseBodyAssetsQr](docs/LoyaltiesMembersTransfersCreateResponseBodyAssetsQr.md)
 - [LoyaltiesMembersTransfersCreateResponseBodyLoyaltyCard](docs/LoyaltiesMembersTransfersCreateResponseBodyLoyaltyCard.md)
 - [LoyaltiesMembersTransfersCreateResponseBodyPublish](docs/LoyaltiesMembersTransfersCreateResponseBodyPublish.md)
 - [LoyaltiesMembersTransfersCreateResponseBodyRedemption](docs/LoyaltiesMembersTransfersCreateResponseBodyRedemption.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBody](docs/LoyaltiesPointsExpirationExportCreateRequestBody.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBodyParameters](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParameters.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBodyParametersFilters](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFilters.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignId](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignId.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignIdConditions](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersCampaignIdConditions.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherId](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherId.md)
 - [LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherIdConditions](docs/LoyaltiesPointsExpirationExportCreateRequestBodyParametersFiltersVoucherIdConditions.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBody](docs/LoyaltiesPointsExpirationExportCreateResponseBody.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBodyParameters](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParameters.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBodyParametersFilters](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFilters.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignId](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignId.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignIdConditions](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersCampaignIdConditions.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherId](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherId.md)
 - [LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherIdConditions](docs/LoyaltiesPointsExpirationExportCreateResponseBodyParametersFiltersVoucherIdConditions.md)
 - [LoyaltiesRewardAssignmentsGetResponseBody](docs/LoyaltiesRewardAssignmentsGetResponseBody.md)
 - [LoyaltiesRewardAssignmentsGetResponseBodyParameters](docs/LoyaltiesRewardAssignmentsGetResponseBodyParameters.md)
 - [LoyaltiesRewardAssignmentsGetResponseBodyParametersLoyalty](docs/LoyaltiesRewardAssignmentsGetResponseBodyParametersLoyalty.md)
 - [LoyaltiesRewardAssignmentsListResponseBody](docs/LoyaltiesRewardAssignmentsListResponseBody.md)
 - [LoyaltiesRewardAssignmentsRewardGetResponseBody](docs/LoyaltiesRewardAssignmentsRewardGetResponseBody.md)
 - [LoyaltiesRewardAssignmentsRewardGetResponseBodyAttributes](docs/LoyaltiesRewardAssignmentsRewardGetResponseBodyAttributes.md)
 - [LoyaltiesRewardsCreateAssignmentItemRequestBody](docs/LoyaltiesRewardsCreateAssignmentItemRequestBody.md)
 - [LoyaltiesRewardsCreateAssignmentItemRequestBodyParameters](docs/LoyaltiesRewardsCreateAssignmentItemRequestBodyParameters.md)
 - [LoyaltiesRewardsCreateAssignmentItemRequestBodyParametersLoyalty](docs/LoyaltiesRewardsCreateAssignmentItemRequestBodyParametersLoyalty.md)
 - [LoyaltiesRewardsCreateAssignmentResponseBody](docs/LoyaltiesRewardsCreateAssignmentResponseBody.md)
 - [LoyaltiesRewardsCreateAssignmentResponseBodyParameters](docs/LoyaltiesRewardsCreateAssignmentResponseBodyParameters.md)
 - [LoyaltiesRewardsCreateAssignmentResponseBodyParametersLoyalty](docs/LoyaltiesRewardsCreateAssignmentResponseBodyParametersLoyalty.md)
 - [LoyaltiesRewardsGetResponseBody](docs/LoyaltiesRewardsGetResponseBody.md)
 - [LoyaltiesRewardsGetResponseBodyParameters](docs/LoyaltiesRewardsGetResponseBodyParameters.md)
 - [LoyaltiesRewardsGetResponseBodyParametersLoyalty](docs/LoyaltiesRewardsGetResponseBodyParametersLoyalty.md)
 - [LoyaltiesRewardsListAssignmentsResponseBody](docs/LoyaltiesRewardsListAssignmentsResponseBody.md)
 - [LoyaltiesRewardsUpdateAssignmentRequestBody](docs/LoyaltiesRewardsUpdateAssignmentRequestBody.md)
 - [LoyaltiesRewardsUpdateAssignmentRequestBodyParameters](docs/LoyaltiesRewardsUpdateAssignmentRequestBodyParameters.md)
 - [LoyaltiesRewardsUpdateAssignmentRequestBodyParametersLoyalty](docs/LoyaltiesRewardsUpdateAssignmentRequestBodyParametersLoyalty.md)
 - [LoyaltiesRewardsUpdateAssignmentResponseBody](docs/LoyaltiesRewardsUpdateAssignmentResponseBody.md)
 - [LoyaltiesRewardsUpdateAssignmentResponseBodyParameters](docs/LoyaltiesRewardsUpdateAssignmentResponseBodyParameters.md)
 - [LoyaltiesRewardsUpdateAssignmentResponseBodyParametersLoyalty](docs/LoyaltiesRewardsUpdateAssignmentResponseBodyParametersLoyalty.md)
 - [LoyaltiesTiersCreateInBulkRequestBodyItem](docs/LoyaltiesTiersCreateInBulkRequestBodyItem.md)
 - [LoyaltiesTiersEarningRulesListResponseBody](docs/LoyaltiesTiersEarningRulesListResponseBody.md)
 - [LoyaltiesTiersGetResponseBody](docs/LoyaltiesTiersGetResponseBody.md)
 - [LoyaltiesTiersGetResponseBodyConfig](docs/LoyaltiesTiersGetResponseBodyConfig.md)
 - [LoyaltiesTiersGetResponseBodyConfigPoints](docs/LoyaltiesTiersGetResponseBodyConfigPoints.md)
 - [LoyaltiesTiersGetResponseBodyPoints](docs/LoyaltiesTiersGetResponseBodyPoints.md)
 - [LoyaltiesTiersListResponseBody](docs/LoyaltiesTiersListResponseBody.md)
 - [LoyaltiesTiersRewardsListResponseBody](docs/LoyaltiesTiersRewardsListResponseBody.md)
 - [LoyaltiesTransferPoints](docs/LoyaltiesTransferPoints.md)
 - [LoyaltiesUpdateCampaignRequestBody](docs/LoyaltiesUpdateCampaignRequestBody.md)
 - [LoyaltiesUpdateCampaignRequestBodyOptions](docs/LoyaltiesUpdateCampaignRequestBodyOptions.md)
 - [LoyaltiesUpdateCampaignResponseBody](docs/LoyaltiesUpdateCampaignResponseBody.md)
 - [LoyaltyCampaign](docs/LoyaltyCampaign.md)
 - [LoyaltyCampaignVoucher](docs/LoyaltyCampaignVoucher.md)
 - [LoyaltyCampaignVoucherRedemption](docs/LoyaltyCampaignVoucherRedemption.md)
 - [LoyaltyCardTransaction](docs/LoyaltyCardTransaction.md)
 - [LoyaltyCardTransactionDetails](docs/LoyaltyCardTransactionDetails.md)
 - [LoyaltyCardTransactionDetailsBalance](docs/LoyaltyCardTransactionDetailsBalance.md)
 - [LoyaltyCardTransactionDetailsBalanceRelatedObject](docs/LoyaltyCardTransactionDetailsBalanceRelatedObject.md)
 - [LoyaltyCardTransactionDetailsCustomEvent](docs/LoyaltyCardTransactionDetailsCustomEvent.md)
 - [LoyaltyCardTransactionDetailsEarningRule](docs/LoyaltyCardTransactionDetailsEarningRule.md)
 - [LoyaltyCardTransactionDetailsEarningRuleSource](docs/LoyaltyCardTransactionDetailsEarningRuleSource.md)
 - [LoyaltyCardTransactionDetailsEvent](docs/LoyaltyCardTransactionDetailsEvent.md)
 - [LoyaltyCardTransactionDetailsEventSchema](docs/LoyaltyCardTransactionDetailsEventSchema.md)
 - [LoyaltyCardTransactionDetailsLoyaltyTier](docs/LoyaltyCardTransactionDetailsLoyaltyTier.md)
 - [LoyaltyCardTransactionDetailsOrder](docs/LoyaltyCardTransactionDetailsOrder.md)
 - [LoyaltyCardTransactionDetailsRedemption](docs/LoyaltyCardTransactionDetailsRedemption.md)
 - [LoyaltyCardTransactionDetailsReward](docs/LoyaltyCardTransactionDetailsReward.md)
 - [LoyaltyCardTransactionDetailsRollback](docs/LoyaltyCardTransactionDetailsRollback.md)
 - [LoyaltyCardTransactionDetailsSegment](docs/LoyaltyCardTransactionDetailsSegment.md)
 - [LoyaltyCardTransactionsType](docs/LoyaltyCardTransactionsType.md)
 - [LoyaltyMember](docs/LoyaltyMember.md)
 - [LoyaltyMemberLoyaltyCard](docs/LoyaltyMemberLoyaltyCard.md)
 - [LoyaltyMemberPublish](docs/LoyaltyMemberPublish.md)
 - [LoyaltyMemberRedemption](docs/LoyaltyMemberRedemption.md)
 - [LoyaltyPointsBucket](docs/LoyaltyPointsBucket.md)
 - [LoyaltyPointsBucketBucket](docs/LoyaltyPointsBucketBucket.md)
 - [LoyaltyTier](docs/LoyaltyTier.md)
 - [LoyaltyTierBase](docs/LoyaltyTierBase.md)
 - [LoyaltyTierBasePoints](docs/LoyaltyTierBasePoints.md)
 - [LoyaltyTierConfig](docs/LoyaltyTierConfig.md)
 - [LoyaltyTierConfigPoints](docs/LoyaltyTierConfigPoints.md)
 - [LoyaltyTierExpiration](docs/LoyaltyTierExpiration.md)
 - [LoyaltyTierPoints](docs/LoyaltyTierPoints.md)
 - [LoyaltyTiersExpirationAll](docs/LoyaltyTiersExpirationAll.md)
 - [LoyaltyTiersExpirationAllExpirationDate](docs/LoyaltyTiersExpirationAllExpirationDate.md)
 - [LoyaltyTiersExpirationAllExpirationDateRounding](docs/LoyaltyTiersExpirationAllExpirationDateRounding.md)
 - [LoyaltyTiersExpirationAllStartDate](docs/LoyaltyTiersExpirationAllStartDate.md)
 - [ManagementProject](docs/ManagementProject.md)
 - [ManagementProjectApiUsageNotifications](docs/ManagementProjectApiUsageNotifications.md)
 - [ManagementProjectDefaultCodeConfig](docs/ManagementProjectDefaultCodeConfig.md)
 - [ManagementProjectLimits](docs/ManagementProjectLimits.md)
 - [ManagementProjectLimitsApiCallsItem](docs/ManagementProjectLimitsApiCallsItem.md)
 - [ManagementProjectLimitsBulkApiCallsItem](docs/ManagementProjectLimitsBulkApiCallsItem.md)
 - [ManagementProjectWebhooksCalloutNotifications](docs/ManagementProjectWebhooksCalloutNotifications.md)
 - [ManagementProjectWebhooksCalloutNotificationsDistributions](docs/ManagementProjectWebhooksCalloutNotificationsDistributions.md)
 - [ManagementProjectWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectWebhooksCalloutNotificationsWebhooks.md)
 - [ManagementProjectsBranding](docs/ManagementProjectsBranding.md)
 - [ManagementProjectsBrandingAddress](docs/ManagementProjectsBrandingAddress.md)
 - [ManagementProjectsBrandingBrand](docs/ManagementProjectsBrandingBrand.md)
 - [ManagementProjectsBrandingCockpits](docs/ManagementProjectsBrandingCockpits.md)
 - [ManagementProjectsBrandingContact](docs/ManagementProjectsBrandingContact.md)
 - [ManagementProjectsBrandingCreateRequestBody](docs/ManagementProjectsBrandingCreateRequestBody.md)
 - [ManagementProjectsBrandingCreateRequestBodyAddress](docs/ManagementProjectsBrandingCreateRequestBodyAddress.md)
 - [ManagementProjectsBrandingCreateRequestBodyBrand](docs/ManagementProjectsBrandingCreateRequestBodyBrand.md)
 - [ManagementProjectsBrandingCreateRequestBodyCockpits](docs/ManagementProjectsBrandingCreateRequestBodyCockpits.md)
 - [ManagementProjectsBrandingCreateRequestBodyContact](docs/ManagementProjectsBrandingCreateRequestBodyContact.md)
 - [ManagementProjectsBrandingCreateResponseBody](docs/ManagementProjectsBrandingCreateResponseBody.md)
 - [ManagementProjectsBrandingCreateResponseBodyAddress](docs/ManagementProjectsBrandingCreateResponseBodyAddress.md)
 - [ManagementProjectsBrandingCreateResponseBodyBrand](docs/ManagementProjectsBrandingCreateResponseBodyBrand.md)
 - [ManagementProjectsBrandingCreateResponseBodyCockpits](docs/ManagementProjectsBrandingCreateResponseBodyCockpits.md)
 - [ManagementProjectsBrandingCreateResponseBodyContact](docs/ManagementProjectsBrandingCreateResponseBodyContact.md)
 - [ManagementProjectsBrandingGetResponseBody](docs/ManagementProjectsBrandingGetResponseBody.md)
 - [ManagementProjectsBrandingGetResponseBodyAddress](docs/ManagementProjectsBrandingGetResponseBodyAddress.md)
 - [ManagementProjectsBrandingGetResponseBodyBrand](docs/ManagementProjectsBrandingGetResponseBodyBrand.md)
 - [ManagementProjectsBrandingGetResponseBodyCockpits](docs/ManagementProjectsBrandingGetResponseBodyCockpits.md)
 - [ManagementProjectsBrandingGetResponseBodyContact](docs/ManagementProjectsBrandingGetResponseBodyContact.md)
 - [ManagementProjectsBrandingListResponseBody](docs/ManagementProjectsBrandingListResponseBody.md)
 - [ManagementProjectsBrandingUpdateRequestBody](docs/ManagementProjectsBrandingUpdateRequestBody.md)
 - [ManagementProjectsBrandingUpdateRequestBodyAddress](docs/ManagementProjectsBrandingUpdateRequestBodyAddress.md)
 - [ManagementProjectsBrandingUpdateRequestBodyBrand](docs/ManagementProjectsBrandingUpdateRequestBodyBrand.md)
 - [ManagementProjectsBrandingUpdateRequestBodyCockpits](docs/ManagementProjectsBrandingUpdateRequestBodyCockpits.md)
 - [ManagementProjectsBrandingUpdateRequestBodyContact](docs/ManagementProjectsBrandingUpdateRequestBodyContact.md)
 - [ManagementProjectsBrandingUpdateResponseBody](docs/ManagementProjectsBrandingUpdateResponseBody.md)
 - [ManagementProjectsBrandingUpdateResponseBodyAddress](docs/ManagementProjectsBrandingUpdateResponseBodyAddress.md)
 - [ManagementProjectsBrandingUpdateResponseBodyBrand](docs/ManagementProjectsBrandingUpdateResponseBodyBrand.md)
 - [ManagementProjectsBrandingUpdateResponseBodyCockpits](docs/ManagementProjectsBrandingUpdateResponseBodyCockpits.md)
 - [ManagementProjectsBrandingUpdateResponseBodyContact](docs/ManagementProjectsBrandingUpdateResponseBodyContact.md)
 - [ManagementProjectsCreateRequestBody](docs/ManagementProjectsCreateRequestBody.md)
 - [ManagementProjectsCreateRequestBodyApiUsageNotifications](docs/ManagementProjectsCreateRequestBodyApiUsageNotifications.md)
 - [ManagementProjectsCreateRequestBodyUsersItem](docs/ManagementProjectsCreateRequestBodyUsersItem.md)
 - [ManagementProjectsCreateRequestBodyWebhooksCalloutNotifications](docs/ManagementProjectsCreateRequestBodyWebhooksCalloutNotifications.md)
 - [ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsDistributions.md)
 - [ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsCreateRequestBodyWebhooksCalloutNotificationsWebhooks.md)
 - [ManagementProjectsCreateResponseBody](docs/ManagementProjectsCreateResponseBody.md)
 - [ManagementProjectsCreateResponseBodyApiUsageNotifications](docs/ManagementProjectsCreateResponseBodyApiUsageNotifications.md)
 - [ManagementProjectsCreateResponseBodyClientSideKey](docs/ManagementProjectsCreateResponseBodyClientSideKey.md)
 - [ManagementProjectsCreateResponseBodyServerSideKey](docs/ManagementProjectsCreateResponseBodyServerSideKey.md)
 - [ManagementProjectsCreateResponseBodyWebhooksCalloutNotifications](docs/ManagementProjectsCreateResponseBodyWebhooksCalloutNotifications.md)
 - [ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsDistributions.md)
 - [ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsCreateResponseBodyWebhooksCalloutNotificationsWebhooks.md)
 - [ManagementProjectsCustomEventSchema](docs/ManagementProjectsCustomEventSchema.md)
 - [ManagementProjectsCustomEventSchemaSchema](docs/ManagementProjectsCustomEventSchemaSchema.md)
 - [ManagementProjectsCustomEventSchemasCreateRequestBody](docs/ManagementProjectsCustomEventSchemasCreateRequestBody.md)
 - [ManagementProjectsCustomEventSchemasCreateRequestBodySchema](docs/ManagementProjectsCustomEventSchemasCreateRequestBodySchema.md)
 - [ManagementProjectsCustomEventSchemasCreateResponseBody](docs/ManagementProjectsCustomEventSchemasCreateResponseBody.md)
 - [ManagementProjectsCustomEventSchemasCreateResponseBodySchema](docs/ManagementProjectsCustomEventSchemasCreateResponseBodySchema.md)
 - [ManagementProjectsCustomEventSchemasGetResponseBody](docs/ManagementProjectsCustomEventSchemasGetResponseBody.md)
 - [ManagementProjectsCustomEventSchemasGetResponseBodySchema](docs/ManagementProjectsCustomEventSchemasGetResponseBodySchema.md)
 - [ManagementProjectsCustomEventSchemasListResponseBody](docs/ManagementProjectsCustomEventSchemasListResponseBody.md)
 - [ManagementProjectsCustomEventSchemasUpdateRequestBody](docs/ManagementProjectsCustomEventSchemasUpdateRequestBody.md)
 - [ManagementProjectsCustomEventSchemasUpdateRequestBodySchema](docs/ManagementProjectsCustomEventSchemasUpdateRequestBodySchema.md)
 - [ManagementProjectsCustomEventSchemasUpdateResponseBody](docs/ManagementProjectsCustomEventSchemasUpdateResponseBody.md)
 - [ManagementProjectsCustomEventSchemasUpdateResponseBodySchema](docs/ManagementProjectsCustomEventSchemasUpdateResponseBodySchema.md)
 - [ManagementProjectsGetResponseBody](docs/ManagementProjectsGetResponseBody.md)
 - [ManagementProjectsGetResponseBodyApiUsageNotifications](docs/ManagementProjectsGetResponseBodyApiUsageNotifications.md)
 - [ManagementProjectsGetResponseBodyDefaultCodeConfig](docs/ManagementProjectsGetResponseBodyDefaultCodeConfig.md)
 - [ManagementProjectsGetResponseBodyLimits](docs/ManagementProjectsGetResponseBodyLimits.md)
 - [ManagementProjectsGetResponseBodyLimitsApiCallsItem](docs/ManagementProjectsGetResponseBodyLimitsApiCallsItem.md)
 - [ManagementProjectsGetResponseBodyLimitsBulkApiCallsItem](docs/ManagementProjectsGetResponseBodyLimitsBulkApiCallsItem.md)
 - [ManagementProjectsGetResponseBodyWebhooksCalloutNotifications](docs/ManagementProjectsGetResponseBodyWebhooksCalloutNotifications.md)
 - [ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsDistributions.md)
 - [ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsGetResponseBodyWebhooksCalloutNotificationsWebhooks.md)
 - [ManagementProjectsListResponseBody](docs/ManagementProjectsListResponseBody.md)
 - [ManagementProjectsMetadataSchema](docs/ManagementProjectsMetadataSchema.md)
 - [ManagementProjectsMetadataSchemasCreateRequestBody](docs/ManagementProjectsMetadataSchemasCreateRequestBody.md)
 - [ManagementProjectsMetadataSchemasCreateResponseBody](docs/ManagementProjectsMetadataSchemasCreateResponseBody.md)
 - [ManagementProjectsMetadataSchemasGetResponseBody](docs/ManagementProjectsMetadataSchemasGetResponseBody.md)
 - [ManagementProjectsMetadataSchemasListResponseBody](docs/ManagementProjectsMetadataSchemasListResponseBody.md)
 - [ManagementProjectsMetadataSchemasUpdateRequestBody](docs/ManagementProjectsMetadataSchemasUpdateRequestBody.md)
 - [ManagementProjectsMetadataSchemasUpdateResponseBody](docs/ManagementProjectsMetadataSchemasUpdateResponseBody.md)
 - [ManagementProjectsStackingRules](docs/ManagementProjectsStackingRules.md)
 - [ManagementProjectsStackingRulesCreateRequestBody](docs/ManagementProjectsStackingRulesCreateRequestBody.md)
 - [ManagementProjectsStackingRulesCreateResponseBody](docs/ManagementProjectsStackingRulesCreateResponseBody.md)
 - [ManagementProjectsStackingRulesGetResponseBody](docs/ManagementProjectsStackingRulesGetResponseBody.md)
 - [ManagementProjectsStackingRulesListResponseBody](docs/ManagementProjectsStackingRulesListResponseBody.md)
 - [ManagementProjectsStackingRulesUpdateRequestBody](docs/ManagementProjectsStackingRulesUpdateRequestBody.md)
 - [ManagementProjectsStackingRulesUpdateResponseBody](docs/ManagementProjectsStackingRulesUpdateResponseBody.md)
 - [ManagementProjectsTemplatesCampaignsCopyCreateRequestBody](docs/ManagementProjectsTemplatesCampaignsCopyCreateRequestBody.md)
 - [ManagementProjectsTemplatesCampaignsCopyCreateResponseBody](docs/ManagementProjectsTemplatesCampaignsCopyCreateResponseBody.md)
 - [ManagementProjectsTemplatesCampaignsListResponseBody](docs/ManagementProjectsTemplatesCampaignsListResponseBody.md)
 - [ManagementProjectsUpdateRequestBody](docs/ManagementProjectsUpdateRequestBody.md)
 - [ManagementProjectsUpdateRequestBodyApiUsageNotifications](docs/ManagementProjectsUpdateRequestBodyApiUsageNotifications.md)
 - [ManagementProjectsUpdateRequestBodyDefaultCodeConfig](docs/ManagementProjectsUpdateRequestBodyDefaultCodeConfig.md)
 - [ManagementProjectsUpdateRequestBodyWebhooksCalloutNotifications](docs/ManagementProjectsUpdateRequestBodyWebhooksCalloutNotifications.md)
 - [ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsDistributions.md)
 - [ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsUpdateRequestBodyWebhooksCalloutNotificationsWebhooks.md)
 - [ManagementProjectsUpdateResponseBody](docs/ManagementProjectsUpdateResponseBody.md)
 - [ManagementProjectsUpdateResponseBodyApiUsageNotifications](docs/ManagementProjectsUpdateResponseBodyApiUsageNotifications.md)
 - [ManagementProjectsUpdateResponseBodyDefaultCodeConfig](docs/ManagementProjectsUpdateResponseBodyDefaultCodeConfig.md)
 - [ManagementProjectsUpdateResponseBodyLimits](docs/ManagementProjectsUpdateResponseBodyLimits.md)
 - [ManagementProjectsUpdateResponseBodyLimitsApiCallsItem](docs/ManagementProjectsUpdateResponseBodyLimitsApiCallsItem.md)
 - [ManagementProjectsUpdateResponseBodyLimitsBulkApiCallsItem](docs/ManagementProjectsUpdateResponseBodyLimitsBulkApiCallsItem.md)
 - [ManagementProjectsUpdateResponseBodyWebhooksCalloutNotifications](docs/ManagementProjectsUpdateResponseBodyWebhooksCalloutNotifications.md)
 - [ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsDistributions](docs/ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsDistributions.md)
 - [ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsWebhooks](docs/ManagementProjectsUpdateResponseBodyWebhooksCalloutNotificationsWebhooks.md)
 - [ManagementProjectsUsersAssignRequestBody](docs/ManagementProjectsUsersAssignRequestBody.md)
 - [ManagementProjectsUsersAssignResponseBody](docs/ManagementProjectsUsersAssignResponseBody.md)
 - [ManagementProjectsUsersGetUserResponseBody](docs/ManagementProjectsUsersGetUserResponseBody.md)
 - [ManagementProjectsUsersInviteCreateRequestBody](docs/ManagementProjectsUsersInviteCreateRequestBody.md)
 - [ManagementProjectsUsersListResponseBody](docs/ManagementProjectsUsersListResponseBody.md)
 - [ManagementProjectsUsersUpdateRoleRequestBody](docs/ManagementProjectsUsersUpdateRoleRequestBody.md)
 - [ManagementProjectsUsersUpdateRoleResponseBody](docs/ManagementProjectsUsersUpdateRoleResponseBody.md)
 - [ManagementProjectsWebhook](docs/ManagementProjectsWebhook.md)
 - [ManagementProjectsWebhooksCreateRequestBody](docs/ManagementProjectsWebhooksCreateRequestBody.md)
 - [ManagementProjectsWebhooksCreateResponseBody](docs/ManagementProjectsWebhooksCreateResponseBody.md)
 - [ManagementProjectsWebhooksGetResponseBody](docs/ManagementProjectsWebhooksGetResponseBody.md)
 - [ManagementProjectsWebhooksListResponseBody](docs/ManagementProjectsWebhooksListResponseBody.md)
 - [ManagementProjectsWebhooksUpdateRequestBody](docs/ManagementProjectsWebhooksUpdateRequestBody.md)
 - [ManagementProjectsWebhooksUpdateResponseBody](docs/ManagementProjectsWebhooksUpdateResponseBody.md)
 - [MemberActivity](docs/MemberActivity.md)
 - [MetadataSchemaDeprecated](docs/MetadataSchemaDeprecated.md)
 - [MetadataSchemasGetResponseBody](docs/MetadataSchemasGetResponseBody.md)
 - [MetadataSchemasListResponseBody](docs/MetadataSchemasListResponseBody.md)
 - [Order](docs/Order.md)
 - [OrderCalculated](docs/OrderCalculated.md)
 - [OrderCalculatedItem](docs/OrderCalculatedItem.md)
 - [OrderCalculatedItemProduct](docs/OrderCalculatedItemProduct.md)
 - [OrderCalculatedItemSku](docs/OrderCalculatedItemSku.md)
 - [OrderItem](docs/OrderItem.md)
 - [OrderItemProduct](docs/OrderItemProduct.md)
 - [OrderItemSku](docs/OrderItemSku.md)
 - [OrdersCreateRequestBody](docs/OrdersCreateRequestBody.md)
 - [OrdersCreateResponseBody](docs/OrdersCreateResponseBody.md)
 - [OrdersExportCreateRequestBody](docs/OrdersExportCreateRequestBody.md)
 - [OrdersExportCreateRequestBodyParameters](docs/OrdersExportCreateRequestBodyParameters.md)
 - [OrdersExportCreateResponseBody](docs/OrdersExportCreateResponseBody.md)
 - [OrdersExportCreateResponseBodyParameters](docs/OrdersExportCreateResponseBodyParameters.md)
 - [OrdersGetResponseBody](docs/OrdersGetResponseBody.md)
 - [OrdersImportCreateRequestBodyItem](docs/OrdersImportCreateRequestBodyItem.md)
 - [OrdersImportCreateResponseBody](docs/OrdersImportCreateResponseBody.md)
 - [OrdersListResponseBody](docs/OrdersListResponseBody.md)
 - [OrdersUpdateRequestBody](docs/OrdersUpdateRequestBody.md)
 - [OrdersUpdateResponseBody](docs/OrdersUpdateResponseBody.md)
 - [ParameterActivityCategory](docs/ParameterActivityCategory.md)
 - [ParameterCampaignType](docs/ParameterCampaignType.md)
 - [ParameterCreatedBeforeAfter](docs/ParameterCreatedBeforeAfter.md)
 - [ParameterExpandListCampaigns](docs/ParameterExpandListCampaigns.md)
 - [ParameterFiltersListBin](docs/ParameterFiltersListBin.md)
 - [ParameterFiltersListBinId](docs/ParameterFiltersListBinId.md)
 - [ParameterFiltersListBinResourceId](docs/ParameterFiltersListBinResourceId.md)
 - [ParameterFiltersListBinResourceName](docs/ParameterFiltersListBinResourceName.md)
 - [ParameterFiltersListBinResourceType](docs/ParameterFiltersListBinResourceType.md)
 - [ParameterFiltersListBinResourceTypeConditions](docs/ParameterFiltersListBinResourceTypeConditions.md)
 - [ParameterFiltersListCampaigns](docs/ParameterFiltersListCampaigns.md)
 - [ParameterFiltersListCampaignsCampaignStatus](docs/ParameterFiltersListCampaignsCampaignStatus.md)
 - [ParameterFiltersListCampaignsCampaignStatusConditions](docs/ParameterFiltersListCampaignsCampaignStatusConditions.md)
 - [ParameterFiltersListCampaignsCategories](docs/ParameterFiltersListCampaignsCategories.md)
 - [ParameterFiltersListCampaignsCategoryIds](docs/ParameterFiltersListCampaignsCategoryIds.md)
 - [ParameterFiltersListCampaignsIsReferralCode](docs/ParameterFiltersListCampaignsIsReferralCode.md)
 - [ParameterFiltersListCampaignsValidityTimeframe](docs/ParameterFiltersListCampaignsValidityTimeframe.md)
 - [ParameterFiltersListCampaignsVoucherType](docs/ParameterFiltersListCampaignsVoucherType.md)
 - [ParameterFiltersListCustomerRedeemables](docs/ParameterFiltersListCustomerRedeemables.md)
 - [ParameterFiltersListCustomerRedeemablesCampaignId](docs/ParameterFiltersListCustomerRedeemablesCampaignId.md)
 - [ParameterFiltersListCustomerRedeemablesCampaignType](docs/ParameterFiltersListCustomerRedeemablesCampaignType.md)
 - [ParameterFiltersListCustomerRedeemablesCampaignTypeConditions](docs/ParameterFiltersListCustomerRedeemablesCampaignTypeConditions.md)
 - [ParameterFiltersListCustomerRedeemablesCreatedAt](docs/ParameterFiltersListCustomerRedeemablesCreatedAt.md)
 - [ParameterFiltersListCustomerRedeemablesHolderRole](docs/ParameterFiltersListCustomerRedeemablesHolderRole.md)
 - [ParameterFiltersListCustomerRedeemablesHolderRoleConditions](docs/ParameterFiltersListCustomerRedeemablesHolderRoleConditions.md)
 - [ParameterFiltersListCustomerRedeemablesId](docs/ParameterFiltersListCustomerRedeemablesId.md)
 - [ParameterFiltersListCustomerRedeemablesRedeemableId](docs/ParameterFiltersListCustomerRedeemablesRedeemableId.md)
 - [ParameterFiltersListCustomerRedeemablesRedeemableObject](docs/ParameterFiltersListCustomerRedeemablesRedeemableObject.md)
 - [ParameterFiltersListCustomerRedeemablesRedeemableObjectConditions](docs/ParameterFiltersListCustomerRedeemablesRedeemableObjectConditions.md)
 - [ParameterFiltersListCustomerRedeemablesVoucherType](docs/ParameterFiltersListCustomerRedeemablesVoucherType.md)
 - [ParameterFiltersListCustomerRedeemablesVoucherTypeConditions](docs/ParameterFiltersListCustomerRedeemablesVoucherTypeConditions.md)
 - [ParameterFiltersListLocations](docs/ParameterFiltersListLocations.md)
 - [ParameterFiltersListLocationsCreatedAt](docs/ParameterFiltersListLocationsCreatedAt.md)
 - [ParameterFiltersListLocationsName](docs/ParameterFiltersListLocationsName.md)
 - [ParameterFiltersListLocationsUpdatedAt](docs/ParameterFiltersListLocationsUpdatedAt.md)
 - [ParameterFiltersListPublications](docs/ParameterFiltersListPublications.md)
 - [ParameterFiltersListPublicationsCampaignName](docs/ParameterFiltersListPublicationsCampaignName.md)
 - [ParameterFiltersListPublicationsCustomerId](docs/ParameterFiltersListPublicationsCustomerId.md)
 - [ParameterFiltersListPublicationsFailureCode](docs/ParameterFiltersListPublicationsFailureCode.md)
 - [ParameterFiltersListPublicationsIsReferralCode](docs/ParameterFiltersListPublicationsIsReferralCode.md)
 - [ParameterFiltersListPublicationsParentObjectId](docs/ParameterFiltersListPublicationsParentObjectId.md)
 - [ParameterFiltersListPublicationsRelatedObjectId](docs/ParameterFiltersListPublicationsRelatedObjectId.md)
 - [ParameterFiltersListPublicationsResult](docs/ParameterFiltersListPublicationsResult.md)
 - [ParameterFiltersListPublicationsSourceId](docs/ParameterFiltersListPublicationsSourceId.md)
 - [ParameterFiltersListPublicationsVoucherType](docs/ParameterFiltersListPublicationsVoucherType.md)
 - [ParameterFiltersListRedemptions](docs/ParameterFiltersListRedemptions.md)
 - [ParameterFiltersListRedemptionsCampaignName](docs/ParameterFiltersListRedemptionsCampaignName.md)
 - [ParameterFiltersListRedemptionsCustomerId](docs/ParameterFiltersListRedemptionsCustomerId.md)
 - [ParameterFiltersListRedemptionsFailureCode](docs/ParameterFiltersListRedemptionsFailureCode.md)
 - [ParameterFiltersListRedemptionsObject](docs/ParameterFiltersListRedemptionsObject.md)
 - [ParameterFiltersListRedemptionsParentRedemptionId](docs/ParameterFiltersListRedemptionsParentRedemptionId.md)
 - [ParameterFiltersListRedemptionsRelatedObjectId](docs/ParameterFiltersListRedemptionsRelatedObjectId.md)
 - [ParameterFiltersListRedemptionsRelatedObjectParentId](docs/ParameterFiltersListRedemptionsRelatedObjectParentId.md)
 - [ParameterFiltersListRedemptionsResult](docs/ParameterFiltersListRedemptionsResult.md)
 - [ParameterFiltersListRedemptionsUserLogin](docs/ParameterFiltersListRedemptionsUserLogin.md)
 - [ParameterFiltersListRedemptionsVoucherCode](docs/ParameterFiltersListRedemptionsVoucherCode.md)
 - [ParameterFiltersListReferralsRedeemableHolders](docs/ParameterFiltersListReferralsRedeemableHolders.md)
 - [ParameterFiltersListReferralsRedeemableHoldersCreatedAt](docs/ParameterFiltersListReferralsRedeemableHoldersCreatedAt.md)
 - [ParameterFiltersListReferralsRedeemableHoldersCustomerId](docs/ParameterFiltersListReferralsRedeemableHoldersCustomerId.md)
 - [ParameterFiltersListReferralsRedeemableHoldersHolderRole](docs/ParameterFiltersListReferralsRedeemableHoldersHolderRole.md)
 - [ParameterFiltersListReferralsRedeemableHoldersHolderRoleConditions](docs/ParameterFiltersListReferralsRedeemableHoldersHolderRoleConditions.md)
 - [ParameterFiltersListReferralsRedeemableHoldersId](docs/ParameterFiltersListReferralsRedeemableHoldersId.md)
 - [ParameterFiltersListTemplates](docs/ParameterFiltersListTemplates.md)
 - [ParameterFiltersListTemplatesCampaignType](docs/ParameterFiltersListTemplatesCampaignType.md)
 - [ParameterFiltersListTemplatesCampaignTypeConditions](docs/ParameterFiltersListTemplatesCampaignTypeConditions.md)
 - [ParameterFiltersListTemplatesId](docs/ParameterFiltersListTemplatesId.md)
 - [ParameterFiltersListTemplatesName](docs/ParameterFiltersListTemplatesName.md)
 - [ParameterOrder](docs/ParameterOrder.md)
 - [ParameterOrderCreatedAt](docs/ParameterOrderCreatedAt.md)
 - [ParameterOrderListAllPromotionStacks](docs/ParameterOrderListAllPromotionStacks.md)
 - [ParameterOrderListBin](docs/ParameterOrderListBin.md)
 - [ParameterOrderListCampaigns](docs/ParameterOrderListCampaigns.md)
 - [ParameterOrderListCustomers](docs/ParameterOrderListCustomers.md)
 - [ParameterOrderListEarningRules](docs/ParameterOrderListEarningRules.md)
 - [ParameterOrderListExports](docs/ParameterOrderListExports.md)
 - [ParameterOrderListLocations](docs/ParameterOrderListLocations.md)
 - [ParameterOrderListLoyaltyTiers](docs/ParameterOrderListLoyaltyTiers.md)
 - [ParameterOrderListOrders](docs/ParameterOrderListOrders.md)
 - [ParameterOrderListPromotionTiers](docs/ParameterOrderListPromotionTiers.md)
 - [ParameterOrderListPromotionTiersClientSide](docs/ParameterOrderListPromotionTiersClientSide.md)
 - [ParameterOrderListPublications](docs/ParameterOrderListPublications.md)
 - [ParameterOrderListRedeemables](docs/ParameterOrderListRedeemables.md)
 - [ParameterOrderListRedemptions](docs/ParameterOrderListRedemptions.md)
 - [ParameterOrderListTransactions](docs/ParameterOrderListTransactions.md)
 - [ParameterOrderListValidationRuleAssignments](docs/ParameterOrderListValidationRuleAssignments.md)
 - [ParameterOrderListValidationRules](docs/ParameterOrderListValidationRules.md)
 - [ParameterOrderVouchers](docs/ParameterOrderVouchers.md)
 - [ParameterResultListPublications](docs/ParameterResultListPublications.md)
 - [ParameterTemplatesList](docs/ParameterTemplatesList.md)
 - [ParameterUpdatedBeforeAfter](docs/ParameterUpdatedBeforeAfter.md)
 - [ParameterVoucherTypeListPublications](docs/ParameterVoucherTypeListPublications.md)
 - [PointsExpirationTypes](docs/PointsExpirationTypes.md)
 - [Product](docs/Product.md)
 - [ProductCollectionsCreateRequestBody](docs/ProductCollectionsCreateRequestBody.md)
 - [ProductCollectionsCreateRequestBodyProductsItem](docs/ProductCollectionsCreateRequestBodyProductsItem.md)
 - [ProductCollectionsCreateResponseBody](docs/ProductCollectionsCreateResponseBody.md)
 - [ProductCollectionsCreateResponseBodyProductsItem](docs/ProductCollectionsCreateResponseBodyProductsItem.md)
 - [ProductCollectionsGetResponseBody](docs/ProductCollectionsGetResponseBody.md)
 - [ProductCollectionsGetResponseBodyProductsItem](docs/ProductCollectionsGetResponseBodyProductsItem.md)
 - [ProductCollectionsItem](docs/ProductCollectionsItem.md)
 - [ProductCollectionsItemProductsItem](docs/ProductCollectionsItemProductsItem.md)
 - [ProductCollectionsListResponseBody](docs/ProductCollectionsListResponseBody.md)
 - [ProductCollectionsProductsListResponseBody](docs/ProductCollectionsProductsListResponseBody.md)
 - [ProductCollectionsProductsListResponseBodyDataItem](docs/ProductCollectionsProductsListResponseBodyDataItem.md)
 - [ProductWithoutSkus](docs/ProductWithoutSkus.md)
 - [ProductsCreateRequestBody](docs/ProductsCreateRequestBody.md)
 - [ProductsCreateResponseBody](docs/ProductsCreateResponseBody.md)
 - [ProductsGetResponseBody](docs/ProductsGetResponseBody.md)
 - [ProductsImportCsvCreateResponseBody](docs/ProductsImportCsvCreateResponseBody.md)
 - [ProductsListResponseBody](docs/ProductsListResponseBody.md)
 - [ProductsMetadataUpdateInBulkRequestBody](docs/ProductsMetadataUpdateInBulkRequestBody.md)
 - [ProductsMetadataUpdateInBulkResponseBody](docs/ProductsMetadataUpdateInBulkResponseBody.md)
 - [ProductsSkusCreateRequestBody](docs/ProductsSkusCreateRequestBody.md)
 - [ProductsSkusCreateResponseBody](docs/ProductsSkusCreateResponseBody.md)
 - [ProductsSkusListResponseBody](docs/ProductsSkusListResponseBody.md)
 - [ProductsSkusUpdateRequestBody](docs/ProductsSkusUpdateRequestBody.md)
 - [ProductsSkusUpdateResponseBody](docs/ProductsSkusUpdateResponseBody.md)
 - [ProductsUpdateInBulkRequestBody](docs/ProductsUpdateInBulkRequestBody.md)
 - [ProductsUpdateInBulkResponseBody](docs/ProductsUpdateInBulkResponseBody.md)
 - [ProductsUpdateRequestBody](docs/ProductsUpdateRequestBody.md)
 - [ProductsUpdateResponseBody](docs/ProductsUpdateResponseBody.md)
 - [PromotionStack](docs/PromotionStack.md)
 - [PromotionStackBase](docs/PromotionStackBase.md)
 - [PromotionStackBaseTiers](docs/PromotionStackBaseTiers.md)
 - [PromotionStackTiers](docs/PromotionStackTiers.md)
 - [PromotionTier](docs/PromotionTier.md)
 - [PromotionTierAction](docs/PromotionTierAction.md)
 - [PromotionTierCampaign](docs/PromotionTierCampaign.md)
 - [PromotionTierCreateParams](docs/PromotionTierCreateParams.md)
 - [PromotionTierCreateParamsAction](docs/PromotionTierCreateParamsAction.md)
 - [PromotionTierSummary](docs/PromotionTierSummary.md)
 - [PromotionTierSummaryOrders](docs/PromotionTierSummaryOrders.md)
 - [PromotionTierSummaryRedemptions](docs/PromotionTierSummaryRedemptions.md)
 - [PromotionTiersList](docs/PromotionTiersList.md)
 - [PromotionsStacksCreateRequestBody](docs/PromotionsStacksCreateRequestBody.md)
 - [PromotionsStacksCreateRequestBodyTiers](docs/PromotionsStacksCreateRequestBodyTiers.md)
 - [PromotionsStacksCreateResponseBody](docs/PromotionsStacksCreateResponseBody.md)
 - [PromotionsStacksCreateResponseBodyTiers](docs/PromotionsStacksCreateResponseBodyTiers.md)
 - [PromotionsStacksGetResponseBody](docs/PromotionsStacksGetResponseBody.md)
 - [PromotionsStacksGetResponseBodyTiers](docs/PromotionsStacksGetResponseBodyTiers.md)
 - [PromotionsStacksListResponseBody](docs/PromotionsStacksListResponseBody.md)
 - [PromotionsStacksUpdateRequestBody](docs/PromotionsStacksUpdateRequestBody.md)
 - [PromotionsStacksUpdateRequestBodyTiers](docs/PromotionsStacksUpdateRequestBodyTiers.md)
 - [PromotionsStacksUpdateResponseBody](docs/PromotionsStacksUpdateResponseBody.md)
 - [PromotionsStacksUpdateResponseBodyTiers](docs/PromotionsStacksUpdateResponseBodyTiers.md)
 - [PromotionsTiersCreateRequestBody](docs/PromotionsTiersCreateRequestBody.md)
 - [PromotionsTiersCreateRequestBodyAction](docs/PromotionsTiersCreateRequestBodyAction.md)
 - [PromotionsTiersCreateResponseBody](docs/PromotionsTiersCreateResponseBody.md)
 - [PromotionsTiersCreateResponseBodyAction](docs/PromotionsTiersCreateResponseBodyAction.md)
 - [PromotionsTiersCreateResponseBodyCampaign](docs/PromotionsTiersCreateResponseBodyCampaign.md)
 - [PromotionsTiersCreateResponseBodySummary](docs/PromotionsTiersCreateResponseBodySummary.md)
 - [PromotionsTiersCreateResponseBodySummaryOrders](docs/PromotionsTiersCreateResponseBodySummaryOrders.md)
 - [PromotionsTiersCreateResponseBodySummaryRedemptions](docs/PromotionsTiersCreateResponseBodySummaryRedemptions.md)
 - [PromotionsTiersDisableResponseBody](docs/PromotionsTiersDisableResponseBody.md)
 - [PromotionsTiersDisableResponseBodyAction](docs/PromotionsTiersDisableResponseBodyAction.md)
 - [PromotionsTiersDisableResponseBodyCampaign](docs/PromotionsTiersDisableResponseBodyCampaign.md)
 - [PromotionsTiersDisableResponseBodySummary](docs/PromotionsTiersDisableResponseBodySummary.md)
 - [PromotionsTiersDisableResponseBodySummaryOrders](docs/PromotionsTiersDisableResponseBodySummaryOrders.md)
 - [PromotionsTiersDisableResponseBodySummaryRedemptions](docs/PromotionsTiersDisableResponseBodySummaryRedemptions.md)
 - [PromotionsTiersEnableResponseBody](docs/PromotionsTiersEnableResponseBody.md)
 - [PromotionsTiersEnableResponseBodyAction](docs/PromotionsTiersEnableResponseBodyAction.md)
 - [PromotionsTiersEnableResponseBodyCampaign](docs/PromotionsTiersEnableResponseBodyCampaign.md)
 - [PromotionsTiersEnableResponseBodySummary](docs/PromotionsTiersEnableResponseBodySummary.md)
 - [PromotionsTiersEnableResponseBodySummaryOrders](docs/PromotionsTiersEnableResponseBodySummaryOrders.md)
 - [PromotionsTiersEnableResponseBodySummaryRedemptions](docs/PromotionsTiersEnableResponseBodySummaryRedemptions.md)
 - [PromotionsTiersGetResponseBody](docs/PromotionsTiersGetResponseBody.md)
 - [PromotionsTiersGetResponseBodyAction](docs/PromotionsTiersGetResponseBodyAction.md)
 - [PromotionsTiersGetResponseBodyCampaign](docs/PromotionsTiersGetResponseBodyCampaign.md)
 - [PromotionsTiersGetResponseBodySummary](docs/PromotionsTiersGetResponseBodySummary.md)
 - [PromotionsTiersGetResponseBodySummaryOrders](docs/PromotionsTiersGetResponseBodySummaryOrders.md)
 - [PromotionsTiersGetResponseBodySummaryRedemptions](docs/PromotionsTiersGetResponseBodySummaryRedemptions.md)
 - [PromotionsTiersListResponseBody](docs/PromotionsTiersListResponseBody.md)
 - [PromotionsTiersUpdateRequestBody](docs/PromotionsTiersUpdateRequestBody.md)
 - [PromotionsTiersUpdateRequestBodyAction](docs/PromotionsTiersUpdateRequestBodyAction.md)
 - [PromotionsTiersUpdateResponseBody](docs/PromotionsTiersUpdateResponseBody.md)
 - [PromotionsTiersUpdateResponseBodyAction](docs/PromotionsTiersUpdateResponseBodyAction.md)
 - [PromotionsTiersUpdateResponseBodyCampaign](docs/PromotionsTiersUpdateResponseBodyCampaign.md)
 - [PromotionsTiersUpdateResponseBodySummary](docs/PromotionsTiersUpdateResponseBodySummary.md)
 - [PromotionsTiersUpdateResponseBodySummaryOrders](docs/PromotionsTiersUpdateResponseBodySummaryOrders.md)
 - [PromotionsTiersUpdateResponseBodySummaryRedemptions](docs/PromotionsTiersUpdateResponseBodySummaryRedemptions.md)
 - [PublicationsCreateRequestBody](docs/PublicationsCreateRequestBody.md)
 - [PublicationsCreateResponseBody](docs/PublicationsCreateResponseBody.md)
 - [PublicationsListResponseBody](docs/PublicationsListResponseBody.md)
 - [PublicationsListResponseBodyPublicationsItem](docs/PublicationsListResponseBodyPublicationsItem.md)
 - [PublicationsListResponseBodyPublicationsItemMetadata](docs/PublicationsListResponseBodyPublicationsItemMetadata.md)
 - [QualificationsCheckEligibilityRequestBody](docs/QualificationsCheckEligibilityRequestBody.md)
 - [QualificationsCheckEligibilityResponseBody](docs/QualificationsCheckEligibilityResponseBody.md)
 - [QualificationsFieldConditions](docs/QualificationsFieldConditions.md)
 - [QualificationsFiltersCondition](docs/QualificationsFiltersCondition.md)
 - [QualificationsOption](docs/QualificationsOption.md)
 - [QualificationsOptionFilters](docs/QualificationsOptionFilters.md)
 - [QualificationsOptionFiltersCampaignType](docs/QualificationsOptionFiltersCampaignType.md)
 - [QualificationsOptionFiltersCampaignTypeConditions](docs/QualificationsOptionFiltersCampaignTypeConditions.md)
 - [QualificationsOptionFiltersHolderRole](docs/QualificationsOptionFiltersHolderRole.md)
 - [QualificationsOptionFiltersHolderRoleConditions](docs/QualificationsOptionFiltersHolderRoleConditions.md)
 - [QualificationsOptionFiltersResourceType](docs/QualificationsOptionFiltersResourceType.md)
 - [QualificationsOptionFiltersResourceTypeConditions](docs/QualificationsOptionFiltersResourceTypeConditions.md)
 - [QualificationsRedeemable](docs/QualificationsRedeemable.md)
 - [QualificationsRedeemableBase](docs/QualificationsRedeemableBase.md)
 - [QualificationsRedeemables](docs/QualificationsRedeemables.md)
 - [RedeemableGift](docs/RedeemableGift.md)
 - [RedeemableHolder](docs/RedeemableHolder.md)
 - [RedeemableLoyaltyCard](docs/RedeemableLoyaltyCard.md)
 - [RedeemableResult](docs/RedeemableResult.md)
 - [RedeemableVoucher](docs/RedeemableVoucher.md)
 - [RedeemableVoucherGift](docs/RedeemableVoucherGift.md)
 - [RedeemableVoucherLoyaltyCard](docs/RedeemableVoucherLoyaltyCard.md)
 - [RedeemableVoucherPublish](docs/RedeemableVoucherPublish.md)
 - [RedeemableVoucherRedemption](docs/RedeemableVoucherRedemption.md)
 - [Redemption](docs/Redemption.md)
 - [RedemptionChannel](docs/RedemptionChannel.md)
 - [RedemptionEntry](docs/RedemptionEntry.md)
 - [RedemptionEntryChannel](docs/RedemptionEntryChannel.md)
 - [RedemptionEntryCustomer](docs/RedemptionEntryCustomer.md)
 - [RedemptionEntryGift](docs/RedemptionEntryGift.md)
 - [RedemptionEntryLoyaltyCard](docs/RedemptionEntryLoyaltyCard.md)
 - [RedemptionEntryOrder](docs/RedemptionEntryOrder.md)
 - [RedemptionEntryOrderCustomer](docs/RedemptionEntryOrderCustomer.md)
 - [RedemptionEntryOrderReferrer](docs/RedemptionEntryOrderReferrer.md)
 - [RedemptionEntryPromotionTier](docs/RedemptionEntryPromotionTier.md)
 - [RedemptionEntryPromotionTierAction](docs/RedemptionEntryPromotionTierAction.md)
 - [RedemptionEntryPromotionTierCampaign](docs/RedemptionEntryPromotionTierCampaign.md)
 - [RedemptionEntryPromotionTierSummary](docs/RedemptionEntryPromotionTierSummary.md)
 - [RedemptionEntryPromotionTierSummaryOrders](docs/RedemptionEntryPromotionTierSummaryOrders.md)
 - [RedemptionEntryPromotionTierSummaryRedemptions](docs/RedemptionEntryPromotionTierSummaryRedemptions.md)
 - [RedemptionEntryRelatedRedemptions](docs/RedemptionEntryRelatedRedemptions.md)
 - [RedemptionEntryRelatedRedemptionsRedemptionsItem](docs/RedemptionEntryRelatedRedemptionsRedemptionsItem.md)
 - [RedemptionEntryRelatedRedemptionsRollbacksItem](docs/RedemptionEntryRelatedRedemptionsRollbacksItem.md)
 - [RedemptionEntryVoucher](docs/RedemptionEntryVoucher.md)
 - [RedemptionEntryVoucherGift](docs/RedemptionEntryVoucherGift.md)
 - [RedemptionEntryVoucherLoyaltyCard](docs/RedemptionEntryVoucherLoyaltyCard.md)
 - [RedemptionEntryVoucherPublish](docs/RedemptionEntryVoucherPublish.md)
 - [RedemptionEntryVoucherRedemption](docs/RedemptionEntryVoucherRedemption.md)
 - [RedemptionGift](docs/RedemptionGift.md)
 - [RedemptionLoyaltyCard](docs/RedemptionLoyaltyCard.md)
 - [RedemptionRelatedRedemptions](docs/RedemptionRelatedRedemptions.md)
 - [RedemptionRelatedRedemptionsRedemptionsItem](docs/RedemptionRelatedRedemptionsRedemptionsItem.md)
 - [RedemptionRelatedRedemptionsRollbacksItem](docs/RedemptionRelatedRedemptionsRollbacksItem.md)
 - [RedemptionRewardResult](docs/RedemptionRewardResult.md)
 - [RedemptionRewardResultParameters](docs/RedemptionRewardResultParameters.md)
 - [RedemptionRewardResultParametersCampaign](docs/RedemptionRewardResultParametersCampaign.md)
 - [RedemptionRewardResultParametersCoin](docs/RedemptionRewardResultParametersCoin.md)
 - [RedemptionRewardResultParametersProduct](docs/RedemptionRewardResultParametersProduct.md)
 - [RedemptionRollback](docs/RedemptionRollback.md)
 - [RedemptionRollbackChannel](docs/RedemptionRollbackChannel.md)
 - [RedemptionRollbackGift](docs/RedemptionRollbackGift.md)
 - [RedemptionRollbackLoyaltyCard](docs/RedemptionRollbackLoyaltyCard.md)
 - [RedemptionRollbackRelatedRedemptions](docs/RedemptionRollbackRelatedRedemptions.md)
 - [RedemptionRollbackRelatedRedemptionsRedemptionsItem](docs/RedemptionRollbackRelatedRedemptionsRedemptionsItem.md)
 - [RedemptionRollbackRelatedRedemptionsRollbacksItem](docs/RedemptionRollbackRelatedRedemptionsRollbacksItem.md)
 - [RedemptionVoucher](docs/RedemptionVoucher.md)
 - [RedemptionVoucherGift](docs/RedemptionVoucherGift.md)
 - [RedemptionVoucherLoyaltyCard](docs/RedemptionVoucherLoyaltyCard.md)
 - [RedemptionVoucherPublish](docs/RedemptionVoucherPublish.md)
 - [RedemptionVoucherRedemption](docs/RedemptionVoucherRedemption.md)
 - [RedemptionsGetResponseBody](docs/RedemptionsGetResponseBody.md)
 - [RedemptionsGetResponseBodyChannel](docs/RedemptionsGetResponseBodyChannel.md)
 - [RedemptionsGetResponseBodyCustomer](docs/RedemptionsGetResponseBodyCustomer.md)
 - [RedemptionsGetResponseBodyGift](docs/RedemptionsGetResponseBodyGift.md)
 - [RedemptionsGetResponseBodyLoyaltyCard](docs/RedemptionsGetResponseBodyLoyaltyCard.md)
 - [RedemptionsGetResponseBodyOrder](docs/RedemptionsGetResponseBodyOrder.md)
 - [RedemptionsGetResponseBodyOrderCustomer](docs/RedemptionsGetResponseBodyOrderCustomer.md)
 - [RedemptionsGetResponseBodyOrderReferrer](docs/RedemptionsGetResponseBodyOrderReferrer.md)
 - [RedemptionsGetResponseBodyPromotionTier](docs/RedemptionsGetResponseBodyPromotionTier.md)
 - [RedemptionsGetResponseBodyPromotionTierAction](docs/RedemptionsGetResponseBodyPromotionTierAction.md)
 - [RedemptionsGetResponseBodyPromotionTierCampaign](docs/RedemptionsGetResponseBodyPromotionTierCampaign.md)
 - [RedemptionsGetResponseBodyPromotionTierSummary](docs/RedemptionsGetResponseBodyPromotionTierSummary.md)
 - [RedemptionsGetResponseBodyPromotionTierSummaryOrders](docs/RedemptionsGetResponseBodyPromotionTierSummaryOrders.md)
 - [RedemptionsGetResponseBodyPromotionTierSummaryRedemptions](docs/RedemptionsGetResponseBodyPromotionTierSummaryRedemptions.md)
 - [RedemptionsGetResponseBodyRelatedRedemptions](docs/RedemptionsGetResponseBodyRelatedRedemptions.md)
 - [RedemptionsGetResponseBodyRelatedRedemptionsRedemptionsItem](docs/RedemptionsGetResponseBodyRelatedRedemptionsRedemptionsItem.md)
 - [RedemptionsGetResponseBodyRelatedRedemptionsRollbacksItem](docs/RedemptionsGetResponseBodyRelatedRedemptionsRollbacksItem.md)
 - [RedemptionsGetResponseBodyVoucher](docs/RedemptionsGetResponseBodyVoucher.md)
 - [RedemptionsGetResponseBodyVoucherGift](docs/RedemptionsGetResponseBodyVoucherGift.md)
 - [RedemptionsGetResponseBodyVoucherLoyaltyCard](docs/RedemptionsGetResponseBodyVoucherLoyaltyCard.md)
 - [RedemptionsGetResponseBodyVoucherPublish](docs/RedemptionsGetResponseBodyVoucherPublish.md)
 - [RedemptionsGetResponseBodyVoucherRedemption](docs/RedemptionsGetResponseBodyVoucherRedemption.md)
 - [RedemptionsListResponseBody](docs/RedemptionsListResponseBody.md)
 - [RedemptionsListResponseBodyRedemptionsItem](docs/RedemptionsListResponseBodyRedemptionsItem.md)
 - [RedemptionsListResponseBodyRedemptionsItemChannel](docs/RedemptionsListResponseBodyRedemptionsItemChannel.md)
 - [RedemptionsListResponseBodyRedemptionsItemCustomer](docs/RedemptionsListResponseBodyRedemptionsItemCustomer.md)
 - [RedemptionsListResponseBodyRedemptionsItemGift](docs/RedemptionsListResponseBodyRedemptionsItemGift.md)
 - [RedemptionsListResponseBodyRedemptionsItemLoyaltyCard](docs/RedemptionsListResponseBodyRedemptionsItemLoyaltyCard.md)
 - [RedemptionsListResponseBodyRedemptionsItemOrder](docs/RedemptionsListResponseBodyRedemptionsItemOrder.md)
 - [RedemptionsListResponseBodyRedemptionsItemOrderCustomer](docs/RedemptionsListResponseBodyRedemptionsItemOrderCustomer.md)
 - [RedemptionsListResponseBodyRedemptionsItemOrderReferrer](docs/RedemptionsListResponseBodyRedemptionsItemOrderReferrer.md)
 - [RedemptionsListResponseBodyRedemptionsItemPromotionTier](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTier.md)
 - [RedemptionsListResponseBodyRedemptionsItemPromotionTierAction](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierAction.md)
 - [RedemptionsListResponseBodyRedemptionsItemPromotionTierCampaign](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierCampaign.md)
 - [RedemptionsListResponseBodyRedemptionsItemPromotionTierSummary](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierSummary.md)
 - [RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryOrders](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryOrders.md)
 - [RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryRedemptions](docs/RedemptionsListResponseBodyRedemptionsItemPromotionTierSummaryRedemptions.md)
 - [RedemptionsListResponseBodyRedemptionsItemRelatedRedemptions](docs/RedemptionsListResponseBodyRedemptionsItemRelatedRedemptions.md)
 - [RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRedemptionsItem](docs/RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRedemptionsItem.md)
 - [RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRollbacksItem](docs/RedemptionsListResponseBodyRedemptionsItemRelatedRedemptionsRollbacksItem.md)
 - [RedemptionsListResponseBodyRedemptionsItemVoucher](docs/RedemptionsListResponseBodyRedemptionsItemVoucher.md)
 - [RedemptionsListResponseBodyRedemptionsItemVoucherGift](docs/RedemptionsListResponseBodyRedemptionsItemVoucherGift.md)
 - [RedemptionsListResponseBodyRedemptionsItemVoucherLoyaltyCard](docs/RedemptionsListResponseBodyRedemptionsItemVoucherLoyaltyCard.md)
 - [RedemptionsListResponseBodyRedemptionsItemVoucherPublish](docs/RedemptionsListResponseBodyRedemptionsItemVoucherPublish.md)
 - [RedemptionsListResponseBodyRedemptionsItemVoucherRedemption](docs/RedemptionsListResponseBodyRedemptionsItemVoucherRedemption.md)
 - [RedemptionsRedeemRequestBody](docs/RedemptionsRedeemRequestBody.md)
 - [RedemptionsRedeemRequestBodyOptions](docs/RedemptionsRedeemRequestBodyOptions.md)
 - [RedemptionsRedeemRequestBodyRedeemablesItem](docs/RedemptionsRedeemRequestBodyRedeemablesItem.md)
 - [RedemptionsRedeemRequestBodyRedeemablesItemGift](docs/RedemptionsRedeemRequestBodyRedeemablesItemGift.md)
 - [RedemptionsRedeemRequestBodyRedeemablesItemReward](docs/RedemptionsRedeemRequestBodyRedeemablesItemReward.md)
 - [RedemptionsRedeemResponseBody](docs/RedemptionsRedeemResponseBody.md)
 - [RedemptionsRollbackCreateRequestBody](docs/RedemptionsRollbackCreateRequestBody.md)
 - [RedemptionsRollbackCreateResponseBody](docs/RedemptionsRollbackCreateResponseBody.md)
 - [RedemptionsRollbackCreateResponseBodyChannel](docs/RedemptionsRollbackCreateResponseBodyChannel.md)
 - [RedemptionsRollbackCreateResponseBodyGift](docs/RedemptionsRollbackCreateResponseBodyGift.md)
 - [RedemptionsRollbackCreateResponseBodyLoyaltyCard](docs/RedemptionsRollbackCreateResponseBodyLoyaltyCard.md)
 - [RedemptionsRollbackCreateResponseBodyRelatedRedemptions](docs/RedemptionsRollbackCreateResponseBodyRelatedRedemptions.md)
 - [RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRedemptionsItem](docs/RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRedemptionsItem.md)
 - [RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRollbacksItem](docs/RedemptionsRollbackCreateResponseBodyRelatedRedemptionsRollbacksItem.md)
 - [RedemptionsRollbacksCreateRequestBody](docs/RedemptionsRollbacksCreateRequestBody.md)
 - [RedemptionsRollbacksCreateResponseBody](docs/RedemptionsRollbacksCreateResponseBody.md)
 - [ReferralProgram](docs/ReferralProgram.md)
 - [ReferralProgramCustomEvent](docs/ReferralProgramCustomEvent.md)
 - [ReferralProgramRefereeReward](docs/ReferralProgramRefereeReward.md)
 - [ReferralProgramRefereeRewardRelatedObjectParent](docs/ReferralProgramRefereeRewardRelatedObjectParent.md)
 - [ReferralsMembersHoldersCreateInBulkRequestBody](docs/ReferralsMembersHoldersCreateInBulkRequestBody.md)
 - [ReferralsMembersHoldersCreateInBulkResponseBody](docs/ReferralsMembersHoldersCreateInBulkResponseBody.md)
 - [ReferralsMembersHoldersListResponseBody](docs/ReferralsMembersHoldersListResponseBody.md)
 - [Referrer](docs/Referrer.md)
 - [ReferrerAddress](docs/ReferrerAddress.md)
 - [ReferrerId](docs/ReferrerId.md)
 - [ResourceTypes](docs/ResourceTypes.md)
 - [Reward](docs/Reward.md)
 - [RewardAssignment](docs/RewardAssignment.md)
 - [RewardAssignmentParameters](docs/RewardAssignmentParameters.md)
 - [RewardAssignmentParametersLoyalty](docs/RewardAssignmentParametersLoyalty.md)
 - [RewardAttributes](docs/RewardAttributes.md)
 - [RewardType](docs/RewardType.md)
 - [RewardTypeCampaign](docs/RewardTypeCampaign.md)
 - [RewardTypeCoin](docs/RewardTypeCoin.md)
 - [RewardTypeProduct](docs/RewardTypeProduct.md)
 - [RewardsAssignmentsCreateRequestBody](docs/RewardsAssignmentsCreateRequestBody.md)
 - [RewardsAssignmentsCreateRequestBodyParameters](docs/RewardsAssignmentsCreateRequestBodyParameters.md)
 - [RewardsAssignmentsCreateRequestBodyParametersLoyalty](docs/RewardsAssignmentsCreateRequestBodyParametersLoyalty.md)
 - [RewardsAssignmentsCreateResponseBody](docs/RewardsAssignmentsCreateResponseBody.md)
 - [RewardsAssignmentsCreateResponseBodyParameters](docs/RewardsAssignmentsCreateResponseBodyParameters.md)
 - [RewardsAssignmentsCreateResponseBodyParametersLoyalty](docs/RewardsAssignmentsCreateResponseBodyParametersLoyalty.md)
 - [RewardsAssignmentsGetResponseBody](docs/RewardsAssignmentsGetResponseBody.md)
 - [RewardsAssignmentsGetResponseBodyParameters](docs/RewardsAssignmentsGetResponseBodyParameters.md)
 - [RewardsAssignmentsGetResponseBodyParametersLoyalty](docs/RewardsAssignmentsGetResponseBodyParametersLoyalty.md)
 - [RewardsAssignmentsListResponseBody](docs/RewardsAssignmentsListResponseBody.md)
 - [RewardsAssignmentsUpdateRequestBody](docs/RewardsAssignmentsUpdateRequestBody.md)
 - [RewardsAssignmentsUpdateRequestBodyParameters](docs/RewardsAssignmentsUpdateRequestBodyParameters.md)
 - [RewardsAssignmentsUpdateRequestBodyParametersLoyalty](docs/RewardsAssignmentsUpdateRequestBodyParametersLoyalty.md)
 - [RewardsAssignmentsUpdateResponseBody](docs/RewardsAssignmentsUpdateResponseBody.md)
 - [RewardsAssignmentsUpdateResponseBodyParameters](docs/RewardsAssignmentsUpdateResponseBodyParameters.md)
 - [RewardsAssignmentsUpdateResponseBodyParametersLoyalty](docs/RewardsAssignmentsUpdateResponseBodyParametersLoyalty.md)
 - [RewardsCreateRequestBody](docs/RewardsCreateRequestBody.md)
 - [RewardsCreateRequestBodyAttributes](docs/RewardsCreateRequestBodyAttributes.md)
 - [RewardsCreateRequestBodyParameters](docs/RewardsCreateRequestBodyParameters.md)
 - [RewardsCreateRequestBodyParametersCampaign](docs/RewardsCreateRequestBodyParametersCampaign.md)
 - [RewardsCreateRequestBodyParametersCoin](docs/RewardsCreateRequestBodyParametersCoin.md)
 - [RewardsCreateRequestBodyParametersProduct](docs/RewardsCreateRequestBodyParametersProduct.md)
 - [RewardsCreateResponseBody](docs/RewardsCreateResponseBody.md)
 - [RewardsCreateResponseBodyAttributes](docs/RewardsCreateResponseBodyAttributes.md)
 - [RewardsListResponseBody](docs/RewardsListResponseBody.md)
 - [RewardsUpdateRequestBody](docs/RewardsUpdateRequestBody.md)
 - [RewardsUpdateRequestBodyAttributes](docs/RewardsUpdateRequestBodyAttributes.md)
 - [RewardsUpdateRequestBodyParameters](docs/RewardsUpdateRequestBodyParameters.md)
 - [RewardsUpdateRequestBodyParametersCampaign](docs/RewardsUpdateRequestBodyParametersCampaign.md)
 - [RewardsUpdateRequestBodyParametersCoin](docs/RewardsUpdateRequestBodyParametersCoin.md)
 - [RewardsUpdateRequestBodyParametersProduct](docs/RewardsUpdateRequestBodyParametersProduct.md)
 - [RewardsUpdateResponseBody](docs/RewardsUpdateResponseBody.md)
 - [RewardsUpdateResponseBodyAttributes](docs/RewardsUpdateResponseBodyAttributes.md)
 - [SegmentsCreateRequestBody](docs/SegmentsCreateRequestBody.md)
 - [SegmentsCreateResponseBody](docs/SegmentsCreateResponseBody.md)
 - [SegmentsGetResponseBody](docs/SegmentsGetResponseBody.md)
 - [Session](docs/Session.md)
 - [SimpleCustomer](docs/SimpleCustomer.md)
 - [SimpleCustomerRequiredObjectType](docs/SimpleCustomerRequiredObjectType.md)
 - [SimpleLoyaltyCard](docs/SimpleLoyaltyCard.md)
 - [SimpleProductDiscountUnit](docs/SimpleProductDiscountUnit.md)
 - [SimpleSegment](docs/SimpleSegment.md)
 - [SimpleSkuDiscountUnit](docs/SimpleSkuDiscountUnit.md)
 - [SimpleVoucher](docs/SimpleVoucher.md)
 - [SimpleVoucherRedemption](docs/SimpleVoucherRedemption.md)
 - [Sku](docs/Sku.md)
 - [SkusGetResponseBody](docs/SkusGetResponseBody.md)
 - [SkusImportCsvCreateResponseBody](docs/SkusImportCsvCreateResponseBody.md)
 - [SkusListForProduct](docs/SkusListForProduct.md)
 - [StackingRules](docs/StackingRules.md)
 - [TemplatesCampaignsCampaignSetupCreateRequestBody](docs/TemplatesCampaignsCampaignSetupCreateRequestBody.md)
 - [TemplatesCampaignsCampaignSetupCreateRequestBodyVoucher](docs/TemplatesCampaignsCampaignSetupCreateRequestBodyVoucher.md)
 - [TemplatesCampaignsCampaignSetupCreateRequestBodyVoucherRedemption](docs/TemplatesCampaignsCampaignSetupCreateRequestBodyVoucherRedemption.md)
 - [TemplatesCampaignsCampaignSetupCreateResponseBody](docs/TemplatesCampaignsCampaignSetupCreateResponseBody.md)
 - [TemplatesCampaignsCampaignSetupCreateResponseBodyCreatedResourcesItem](docs/TemplatesCampaignsCampaignSetupCreateResponseBodyCreatedResourcesItem.md)
 - [TemplatesCampaignsCreateRequestBody](docs/TemplatesCampaignsCreateRequestBody.md)
 - [TemplatesCampaignsCreateTemplateResponseBody](docs/TemplatesCampaignsCreateTemplateResponseBody.md)
 - [TemplatesCampaignsGetResponseBody](docs/TemplatesCampaignsGetResponseBody.md)
 - [TemplatesCampaignsListResponseBody](docs/TemplatesCampaignsListResponseBody.md)
 - [TemplatesCampaignsTierSetupCreateRequestBody](docs/TemplatesCampaignsTierSetupCreateRequestBody.md)
 - [TemplatesCampaignsTierSetupCreateResponseBody](docs/TemplatesCampaignsTierSetupCreateResponseBody.md)
 - [TemplatesCampaignsTierSetupCreateResponseBodyCreatedResourcesItem](docs/TemplatesCampaignsTierSetupCreateResponseBodyCreatedResourcesItem.md)
 - [TemplatesCampaignsUpdateRequestBody](docs/TemplatesCampaignsUpdateRequestBody.md)
 - [TemplatesCampaignsUpdateResponseBody](docs/TemplatesCampaignsUpdateResponseBody.md)
 - [TrashBinItem](docs/TrashBinItem.md)
 - [TrashBinListResponseBody](docs/TrashBinListResponseBody.md)
 - [UsageNotifications](docs/UsageNotifications.md)
 - [User](docs/User.md)
 - [ValidationRule](docs/ValidationRule.md)
 - [ValidationRuleApplicableTo](docs/ValidationRuleApplicableTo.md)
 - [ValidationRuleAssignment](docs/ValidationRuleAssignment.md)
 - [ValidationRuleAssignmentsList](docs/ValidationRuleAssignmentsList.md)
 - [ValidationRuleError](docs/ValidationRuleError.md)
 - [ValidationRulesAssignmentsCreateRequestBody](docs/ValidationRulesAssignmentsCreateRequestBody.md)
 - [ValidationRulesAssignmentsCreateResponseBody](docs/ValidationRulesAssignmentsCreateResponseBody.md)
 - [ValidationRulesAssignmentsList](docs/ValidationRulesAssignmentsList.md)
 - [ValidationRulesAssignmentsListResponseBody](docs/ValidationRulesAssignmentsListResponseBody.md)
 - [ValidationRulesCreateRequestBody](docs/ValidationRulesCreateRequestBody.md)
 - [ValidationRulesCreateRequestBodyApplicableTo](docs/ValidationRulesCreateRequestBodyApplicableTo.md)
 - [ValidationRulesCreateRequestBodyError](docs/ValidationRulesCreateRequestBodyError.md)
 - [ValidationRulesCreateResponseBody](docs/ValidationRulesCreateResponseBody.md)
 - [ValidationRulesCreateResponseBodyApplicableTo](docs/ValidationRulesCreateResponseBodyApplicableTo.md)
 - [ValidationRulesCreateResponseBodyError](docs/ValidationRulesCreateResponseBodyError.md)
 - [ValidationRulesGetResponseBody](docs/ValidationRulesGetResponseBody.md)
 - [ValidationRulesGetResponseBodyApplicableTo](docs/ValidationRulesGetResponseBodyApplicableTo.md)
 - [ValidationRulesGetResponseBodyError](docs/ValidationRulesGetResponseBodyError.md)
 - [ValidationRulesListResponseBody](docs/ValidationRulesListResponseBody.md)
 - [ValidationRulesUpdateRequestBody](docs/ValidationRulesUpdateRequestBody.md)
 - [ValidationRulesUpdateRequestBodyApplicableTo](docs/ValidationRulesUpdateRequestBodyApplicableTo.md)
 - [ValidationRulesUpdateRequestBodyError](docs/ValidationRulesUpdateRequestBodyError.md)
 - [ValidationRulesUpdateResponseBody](docs/ValidationRulesUpdateResponseBody.md)
 - [ValidationRulesUpdateResponseBodyApplicableTo](docs/ValidationRulesUpdateResponseBodyApplicableTo.md)
 - [ValidationRulesUpdateResponseBodyError](docs/ValidationRulesUpdateResponseBodyError.md)
 - [ValidationsRedeemableInapplicable](docs/ValidationsRedeemableInapplicable.md)
 - [ValidationsRedeemableInapplicableResult](docs/ValidationsRedeemableInapplicableResult.md)
 - [ValidationsRedeemableInapplicableResultDetails](docs/ValidationsRedeemableInapplicableResultDetails.md)
 - [ValidationsRedeemableSkipped](docs/ValidationsRedeemableSkipped.md)
 - [ValidationsRedeemableSkippedResult](docs/ValidationsRedeemableSkippedResult.md)
 - [ValidationsRedeemableSkippedResultDetails](docs/ValidationsRedeemableSkippedResultDetails.md)
 - [ValidationsValidateRequestBody](docs/ValidationsValidateRequestBody.md)
 - [ValidationsValidateRequestBodyOptions](docs/ValidationsValidateRequestBodyOptions.md)
 - [ValidationsValidateRequestBodyRedeemablesItem](docs/ValidationsValidateRequestBodyRedeemablesItem.md)
 - [ValidationsValidateRequestBodyRedeemablesItemGift](docs/ValidationsValidateRequestBodyRedeemablesItemGift.md)
 - [ValidationsValidateRequestBodyRedeemablesItemReward](docs/ValidationsValidateRequestBodyRedeemablesItemReward.md)
 - [ValidationsValidateResponseBody](docs/ValidationsValidateResponseBody.md)
 - [ValidationsValidateResponseBodyRedeemablesItem](docs/ValidationsValidateResponseBodyRedeemablesItem.md)
 - [ValidationsValidateResponseBodyRedeemablesItemResult](docs/ValidationsValidateResponseBodyRedeemablesItemResult.md)
 - [ValidationsValidateResponseBodyRedeemablesItemResultDetails](docs/ValidationsValidateResponseBodyRedeemablesItemResultDetails.md)
 - [ValidationsValidateResponseBodyRedeemablesItemResultDiscount](docs/ValidationsValidateResponseBodyRedeemablesItemResultDiscount.md)
 - [ValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct](docs/ValidationsValidateResponseBodyRedeemablesItemResultDiscountProduct.md)
 - [ValidationsValidateResponseBodyRedeemablesItemResultGift](docs/ValidationsValidateResponseBodyRedeemablesItemResultGift.md)
 - [ValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard](docs/ValidationsValidateResponseBodyRedeemablesItemResultLoyaltyCard.md)
 - [ValidityHours](docs/ValidityHours.md)
 - [ValidityHoursDailyItem](docs/ValidityHoursDailyItem.md)
 - [ValidityTimeframe](docs/ValidityTimeframe.md)
 - [Voucher](docs/Voucher.md)
 - [VoucherAssets](docs/VoucherAssets.md)
 - [VoucherAssetsBarcode](docs/VoucherAssetsBarcode.md)
 - [VoucherAssetsQr](docs/VoucherAssetsQr.md)
 - [VoucherBalance](docs/VoucherBalance.md)
 - [VoucherBalanceRelatedObject](docs/VoucherBalanceRelatedObject.md)
 - [VoucherGift](docs/VoucherGift.md)
 - [VoucherLoyaltyCard](docs/VoucherLoyaltyCard.md)
 - [VoucherPublish](docs/VoucherPublish.md)
 - [VoucherRedemption](docs/VoucherRedemption.md)
 - [VoucherTransaction](docs/VoucherTransaction.md)
 - [VoucherTransactionDetails](docs/VoucherTransactionDetails.md)
 - [VoucherTransactionDetailsBalance](docs/VoucherTransactionDetailsBalance.md)
 - [VoucherTransactionDetailsBalanceRelatedObject](docs/VoucherTransactionDetailsBalanceRelatedObject.md)
 - [VoucherTransactionDetailsCustomEvent](docs/VoucherTransactionDetailsCustomEvent.md)
 - [VoucherTransactionDetailsEarningRule](docs/VoucherTransactionDetailsEarningRule.md)
 - [VoucherTransactionDetailsEarningRuleSource](docs/VoucherTransactionDetailsEarningRuleSource.md)
 - [VoucherTransactionDetailsEvent](docs/VoucherTransactionDetailsEvent.md)
 - [VoucherTransactionDetailsEventSchema](docs/VoucherTransactionDetailsEventSchema.md)
 - [VoucherTransactionDetailsLoyaltyTier](docs/VoucherTransactionDetailsLoyaltyTier.md)
 - [VoucherTransactionDetailsOrder](docs/VoucherTransactionDetailsOrder.md)
 - [VoucherTransactionDetailsRedemption](docs/VoucherTransactionDetailsRedemption.md)
 - [VoucherTransactionDetailsReward](docs/VoucherTransactionDetailsReward.md)
 - [VoucherTransactionDetailsRollback](docs/VoucherTransactionDetailsRollback.md)
 - [VoucherTransactionDetailsSegment](docs/VoucherTransactionDetailsSegment.md)
 - [VoucherTransactionsExportFilterConditions](docs/VoucherTransactionsExportFilterConditions.md)
 - [VoucherTransactionsExportFilterConditionsVoucherId](docs/VoucherTransactionsExportFilterConditionsVoucherId.md)
 - [VoucherTransactionsExportFilterConditionsVoucherIdConditions](docs/VoucherTransactionsExportFilterConditionsVoucherIdConditions.md)
 - [VoucherTransactionsExportParameters](docs/VoucherTransactionsExportParameters.md)
 - [VoucherTransactionsFilters](docs/VoucherTransactionsFilters.md)
 - [VoucherWithCategories](docs/VoucherWithCategories.md)
 - [VoucherWithCategoriesGift](docs/VoucherWithCategoriesGift.md)
 - [VoucherWithCategoriesLoyaltyCard](docs/VoucherWithCategoriesLoyaltyCard.md)
 - [VoucherWithCategoriesPublish](docs/VoucherWithCategoriesPublish.md)
 - [VoucherWithCategoriesRedemption](docs/VoucherWithCategoriesRedemption.md)
 - [VouchersBalanceUpdateRequestBody](docs/VouchersBalanceUpdateRequestBody.md)
 - [VouchersBalanceUpdateResponseBody](docs/VouchersBalanceUpdateResponseBody.md)
 - [VouchersBalanceUpdateResponseBodyRelatedObject](docs/VouchersBalanceUpdateResponseBodyRelatedObject.md)
 - [VouchersCreateRequestBody](docs/VouchersCreateRequestBody.md)
 - [VouchersCreateRequestBodyRedemption](docs/VouchersCreateRequestBodyRedemption.md)
 - [VouchersCreateResponseBody](docs/VouchersCreateResponseBody.md)
 - [VouchersCreateResponseBodyGift](docs/VouchersCreateResponseBodyGift.md)
 - [VouchersCreateResponseBodyLoyaltyCard](docs/VouchersCreateResponseBodyLoyaltyCard.md)
 - [VouchersCreateResponseBodyPublish](docs/VouchersCreateResponseBodyPublish.md)
 - [VouchersCreateResponseBodyRedemption](docs/VouchersCreateResponseBodyRedemption.md)
 - [VouchersCreateWithSpecificCodeRequestBody](docs/VouchersCreateWithSpecificCodeRequestBody.md)
 - [VouchersCreateWithSpecificCodeRequestBodyRedemption](docs/VouchersCreateWithSpecificCodeRequestBodyRedemption.md)
 - [VouchersDisableResponseBody](docs/VouchersDisableResponseBody.md)
 - [VouchersDisableResponseBodyGift](docs/VouchersDisableResponseBodyGift.md)
 - [VouchersDisableResponseBodyLoyaltyCard](docs/VouchersDisableResponseBodyLoyaltyCard.md)
 - [VouchersDisableResponseBodyPublish](docs/VouchersDisableResponseBodyPublish.md)
 - [VouchersDisableResponseBodyRedemption](docs/VouchersDisableResponseBodyRedemption.md)
 - [VouchersEnableResponseBody](docs/VouchersEnableResponseBody.md)
 - [VouchersEnableResponseBodyGift](docs/VouchersEnableResponseBodyGift.md)
 - [VouchersEnableResponseBodyLoyaltyCard](docs/VouchersEnableResponseBodyLoyaltyCard.md)
 - [VouchersEnableResponseBodyPublish](docs/VouchersEnableResponseBodyPublish.md)
 - [VouchersEnableResponseBodyRedemption](docs/VouchersEnableResponseBodyRedemption.md)
 - [VouchersGetResponseBody](docs/VouchersGetResponseBody.md)
 - [VouchersGetResponseBodyGift](docs/VouchersGetResponseBodyGift.md)
 - [VouchersGetResponseBodyLoyaltyCard](docs/VouchersGetResponseBodyLoyaltyCard.md)
 - [VouchersGetResponseBodyPublish](docs/VouchersGetResponseBodyPublish.md)
 - [VouchersGetResponseBodyRedemption](docs/VouchersGetResponseBodyRedemption.md)
 - [VouchersImportCreateItemRequestBody](docs/VouchersImportCreateItemRequestBody.md)
 - [VouchersImportCreateItemRequestBodyRedemption](docs/VouchersImportCreateItemRequestBodyRedemption.md)
 - [VouchersImportCreateResponseBody](docs/VouchersImportCreateResponseBody.md)
 - [VouchersImportCsvCreateResponseBody](docs/VouchersImportCsvCreateResponseBody.md)
 - [VouchersListResponseBody](docs/VouchersListResponseBody.md)
 - [VouchersMetadataUpdateInBulkRequestBody](docs/VouchersMetadataUpdateInBulkRequestBody.md)
 - [VouchersMetadataUpdateInBulkResponseBody](docs/VouchersMetadataUpdateInBulkResponseBody.md)
 - [VouchersRedemptionGetResponseBody](docs/VouchersRedemptionGetResponseBody.md)
 - [VouchersTransactionsExportCreateRequestBody](docs/VouchersTransactionsExportCreateRequestBody.md)
 - [VouchersTransactionsExportCreateResponseBody](docs/VouchersTransactionsExportCreateResponseBody.md)
 - [VouchersTransactionsExportCreateResponseBodyResult](docs/VouchersTransactionsExportCreateResponseBodyResult.md)
 - [VouchersTransactionsListResponseBody](docs/VouchersTransactionsListResponseBody.md)
 - [VouchersUpdateInBulkItemRequestBody](docs/VouchersUpdateInBulkItemRequestBody.md)
 - [VouchersUpdateInBulkResponseBody](docs/VouchersUpdateInBulkResponseBody.md)
 - [VouchersUpdateRequestBody](docs/VouchersUpdateRequestBody.md)
 - [VouchersUpdateResponseBody](docs/VouchersUpdateResponseBody.md)
 - [VouchersUpdateResponseBodyGift](docs/VouchersUpdateResponseBodyGift.md)
 - [VouchersUpdateResponseBodyLoyaltyCard](docs/VouchersUpdateResponseBodyLoyaltyCard.md)
 - [VouchersUpdateResponseBodyPublish](docs/VouchersUpdateResponseBodyPublish.md)
 - [VouchersUpdateResponseBodyRedemption](docs/VouchersUpdateResponseBodyRedemption.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="X-App-Id"></a>
### X-App-Id

- **Type**: API key
- **API key parameter name**: X-App-Id
- **Location**: HTTP header

<a id="X-App-Token"></a>
### X-App-Token

- **Type**: API key
- **API key parameter name**: X-App-Token
- **Location**: HTTP header

<a id="X-Client-Token"></a>
### X-Client-Token

- **Type**: API key
- **API key parameter name**: X-Client-Token
- **Location**: HTTP header

<a id="X-Client-Application-Id"></a>
### X-Client-Application-Id

- **Type**: API key
- **API key parameter name**: X-Client-Application-Id
- **Location**: HTTP header

<a id="X-Management-Id"></a>
### X-Management-Id

- **Type**: API key
- **API key parameter name**: X-Management-Id
- **Location**: HTTP header

<a id="X-Management-Token"></a>
### X-Management-Token

- **Type**: API key
- **API key parameter name**: X-Management-Token
- **Location**: HTTP header


## Author

support@voucherify.io


